#
# spec file for package vte
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sover   -2_91-0
%define _apiver  2.91
%define _binver  2_91
%define _apiver4 3.91
%define _binver4 3_91
%define _name    vte

%bcond_without  gtk4_support
%bcond_with     glade_support

Name:           vte
Version:        0.76.1
Release:        1.1
Summary:        Terminal Emulator Library
License:        CC-BY-4.0 AND LGPL-3.0-or-later AND GPL-3.0-or-later AND MIT
Group:          Development/Libraries/GNOME
URL:            https://gitlab.gnome.org/GNOME/vte
Source:         %{_name}-%{version}.tar.zst
# PATCH-FIX-OPENSUSE vte-enable-build-flag-pie.patch yfjiang@suse.com -- enable PIE flag to be compatible with gcc default linking option
Patch0:         vte-enable-build-flag-pie.patch

# PATCH-FIX-SLE vte-revert-back-to-c++17.patch yu.daike@suse.com -- revert c++20 features back to c++17
Patch100:       vte-revert-back-to-c++17.patch

BuildRequires:  c++_compiler
BuildRequires:  fdupes
%if %{with glade_support}
BuildRequires:  glade
%endif
BuildRequires:  gobject-introspection-devel
BuildRequires:  gperf
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  (python3-dataclasses if python3-base < 3.7)
BuildRequires:  pkgconfig(fribidi) >= 1.0.0
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gnutls) >= 3.2.7
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.16.0
%if %{with gtk4_support}
BuildRequires:  pkgconfig(gtk4) >= 4.14.0
%endif
BuildRequires:  pkgconfig(liblz4) >= 1.9
BuildRequires:  pkgconfig(libpcre2-8) >= 10.21
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(pango) >= 1.22.0
BuildRequires:  pkgconfig(vapigen) >= 0.24
BuildRequires:  pkgconfig(zlib)

%description
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

%package -n libvte%{_sover}
Summary:        Terminal Emulator Library
# Needed to make lang package installable (and because we used to
# have a vte package earlier).
License:        LGPL-2.0-only
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libvte%{_sover}
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

%package -n typelib-1_0-Vte-%{?_binver}
Summary:        Introspection bindings for the VTE terminal emulator library
License:        LGPL-2.0-only
Group:          System/Libraries
Provides:       typelib-1_0-Vte-%{_apiver} = %{version}
Obsoletes:      typelib-1_0-Vte-%{_apiver} < %{version}

%description -n typelib-1_0-Vte-%{?_binver}
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides the GObject Introspection bindings for VTE.

%package tools
Summary:        Tools from the VTE terminal emulator package
License:        LGPL-2.0-only
Group:          System/Libraries

%description tools
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides tools using VTE.

%if %{with gtk4_support}
%package -n typelib-1_0-Vte-%{?_binver4}
Summary:        Introspection bindings for the VTE terminal emulator library
License:        LGPL-2.0-only
Group:          System/Libraries

%description -n typelib-1_0-Vte-%{?_binver4}
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides the GObject Introspection bindings for VTE.

%package tools-gtk4
Summary:        Tools from the VTE terminal emulator package
License:        LGPL-2.0-only
Group:          System/Libraries

%description tools-gtk4
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides tools using VTE.
%endif

%package devel
Summary:        Development files for the VTE terminal emulator library
License:        LGPL-2.0-only
Group:          Development/Libraries/GNOME
Requires:       libvte%{_sover} = %{version}
Requires:       typelib-1_0-Vte-%{?_binver} = %{version}
%if %{with gtk4_support}
Requires:       typelib-1_0-Vte-%{?_binver4} = %{version}
%endif
Provides:       vte-doc = %{version}
Obsoletes:      vte-doc < %{version}

%description devel
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package contains the files needed for building applications using
VTE.

%if %{with glade_support}
%package -n glade-catalog-vte
Summary:        Glade catalog for vte
License:        CC-BY-4.0 AND LGPL-3.0-or-later AND GPL-3.0-or-later AND MIT
Group:          Development/Tools/GUI Builders
Requires:       %{name} = %{version}
Requires:       glade
Supplements:    (glade and %{name}-devel)
BuildArch:      noarch

%description -n glade-catalog-vte
This package provides a catalog for Glade, to allow the use the vte
widgets in Glade.
%endif

%lang_package

%prep
%autosetup -n %{_name}-%{version} -N
%patch -P 0 -p1
%if 0%{?sle_version}
%patch -P 100 -p1
%endif

%build
%meson \
	-Ddocs=true \
%if %{with gtk4_support}
	-Dgtk4=true \
%endif
%if %{with glade_support}
	-Dglade=true \
%else
	-Dglade=false \
%endif
	%{nil}
%meson_build

%install
%meson_install

%find_lang vte-%{_apiver}
%fdupes %{buildroot}%{_prefix}

# Make default docdir ref openSUSE standard
mkdir -p %{buildroot}%{_docdir}/vte-%{_apiver}
%if %{with gtk4_support}
mkdir -p %{buildroot}%{_docdir}/vte-%{_apiver}-gtk4
%endif
# Move docs from upstream docdir to openSUSE docdir standard
mv %{buildroot}%{_datadir}/doc/vte-%{_apiver} %{buildroot}%{_docdir}
%if %{with gtk4_support}
mv %{buildroot}%{_datadir}/doc/vte-%{_apiver}-gtk4 %{buildroot}%{_docdir}
%endif

%ldconfig_scriptlets -n libvte%{_sover}

%files -n libvte%{_sover}
%license COPYING.CC-BY-4-0 COPYING.GPL3 COPYING.LGPL3 COPYING.XTERM
%{_libdir}/*.so.*
%config %{_sysconfdir}/profile.d/vte.sh
%config %{_sysconfdir}/profile.d/vte.csh
%dir %{_userunitdir}/vte-spawn-.scope.d
%{_userunitdir}/vte-spawn-.scope.d/defaults.conf
%{_libexecdir}/vte-urlencode-cwd

%files -n typelib-1_0-Vte-%{?_binver}
%{_libdir}/girepository-1.0/Vte-%{_apiver}.typelib

%files tools
%{_bindir}/vte-%{?_apiver}

%if %{with gtk4_support}
%files -n typelib-1_0-Vte-%{?_binver4}
%{_libdir}/girepository-1.0/Vte-%{_apiver4}.typelib

%files tools-gtk4
%{_bindir}/vte-%{?_apiver}-gtk4
%endif

%files devel
%doc AUTHORS
%doc %{_docdir}/vte-%{_apiver}/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_includedir}/vte-%{_apiver}/
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/vte-%{_apiver}.vapi
%{_datadir}/vala/vapi/vte-%{_apiver}.deps

%if %{with gtk4_support}
%{_includedir}/vte-%{_apiver}-gtk4/
%doc %{_docdir}/vte-%{_apiver}-gtk4/
%{_datadir}/vala/vapi/vte-%{_apiver}-gtk4.deps
%{_datadir}/vala/vapi/vte-%{_apiver}-gtk4.vapi
%endif

%if %{with glade_support}
%files -n glade-catalog-vte
%{_datadir}/glade/catalogs/vte-%{_apiver}.xml
%{_datadir}/glade/pixmaps/hicolor/16x16/actions/widget-vte-terminal.png
%{_datadir}/glade/pixmaps/hicolor/22x22/actions/widget-vte-terminal.png
%endif

%files lang -f vte-%{_apiver}.lang

%changelog
* Thu May  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.76.1:
  + terminal: fix UTF-8 bounds check.
  + app: Don't hide scrolled-window option.
  + app: Add built-in CSS to hide scrolled-window over-scroll
    indicators.
  + emulation: Fix the reported bold/etc. color if unset
  + widget: Also set tag when returning no match.
* Thu May  2 2024 dimstar@opensuse.org
- Update to version 0.76.1:
  * emulation: Fix the reported bold/etc. color if unset
  * app: Fix the build with clang++
  * app: Don't use typeof
  * terminal: fix UTF-8 bounds check
  * widget: Also set tag when returning no match
  * app: Add built-in CSS to hide scrolled-window over-scroll indicators
  * app: Don't hide scrolled-window option
  * build: Post release version bump
* Mon Mar 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.76.0:
  + gtk3: draw: minifont: Don't do minifont caching.
  + widget: Add im_activate_osk() method.
  + widget: Activate OSK on button release.
* Mon Mar 18 2024 dimstar@opensuse.org
- Update to version 0.76.0:
  * build: Version 0.76.0
  * build: Bump gtk4 req version
  * widget: Activate OSK on button release
  * widget: Add im_activate_osk() method
  * gtk3: draw: minifont: Don't do minifont caching
  * build: Post release version bump
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.75.92:
  + widget: Make backwards search find wrapped words.
  + widget: Bit of cleanup around the previous fix.
  + widget: gtk4: Fix double and triple click handling.
  + widget: Faster rewrapping on resize.
  + lib: Remember the Terminal in ProcessingContext.
  + lib: Batch handling of single-width characters.
  + ring: Only occasionally advance the stream tails.
  + widget: gtk4: Fix the look of outline block cursor in the first
    column.
  + vte.sh: Avoid warning if shell is configured with 'set -u'.
  + widget: a11y: Add missing text changes on scrolling with
    modifications.
* Mon Mar  4 2024 dimstar@opensuse.org
- Update to version 0.75.92:
  * fonts: Allow unknown coverage to silently pass through
  * widget: Fix end alignment
  * app: Rework argument parsing
  * widget: gtk4: Fix the look of outline block cursor in the first column
  * ringview: inline get_bidirow()
  * bidi: inline log2vis() and vis2log()
  * terminal: inline hot path of cell_is_selected_log()
  * terminal: annotate unlikely paths in determine_colors()
  * terminal: remove determine_colors() invisible check
  * Revert "widget: Limit select-all to the writable region not including the scrollback"
  * vte.sh: Avoid warning if shell is configured with 'set -u'
  * widget: Set scroll-on-insert to false by default
  * scheduler: add 10hz fallback scheduler
  * widget: Try to fix a build failure on 32-bit archs
  * ring: Only occasionally advance the stream tails
  * lib: Batch handling of single-width characters
  * lib: Remember the Terminal in ProcessingContext
  * widget: Faster rewrapping on resize
  * widget: gtk4: Fix double and triple click handling
  * widget: Bit of cleanup around the previous fix
  * widget: Make backwards search find wrapped words
  * Revert "build: Remove extra debug compile option"
  * widget: a11y: Add missing text changes on scrolling with modifications
  * widget: Add type annotation to setup-context-menu signal
  * build: Post release version bump
* Mon Feb 12 2024 dimstar@opensuse.org
- Update to version 0.75.91:
  * vte.sh: Consistent indentation
  * vte.sh: Set up bash and zsh for OSC 133 shell integration
  * emulation: Support conditional new paragraph
  * emulation: Track shell integration escape sequences
  * lib: Remove pointless "maybe" in some method names
  * all: Remove SIXEL support from stable branch
  * widget: Remove termprops from stable branch
  * widget: termprops: Reset termprops on terminal reset
  * widget: termprops: Rewrite termprop documentation
  * widget: termprops: Unify int types
  * widget: Fix HTML CSS property "text-decoration-style: solid"
  * widget,emulation: Add support for dotted and dashed underlines
  * widget: termprops: Relax boolean value parsing
  * widget: termprops: String value parsing fixes
  * widget: termprops: Add some more tests
  * widget: termprops: Allow true/false for BOOL termprops
  * widget: termprops: Add DOUBLE type
  * emulation: Allow default parameter value for XTVERSION
  * emulation: Support XTVERSION sequence
  * emulation: Reply to DECRQPSR and DECRQTSR
  * emulation: More accurate DA1 and DA2 replies
  * widget: Renumber VterAlign enum
  * emulation: Also reply to DECRQSS on XTERM_MODKEYS
  * emulation: Remove xterm alias for DSR_DEC 53
  * widget: Add terminal properties
  * lib: Add some colour helper classes
  * lib: Add a simple UUID class
  * widget: Don't throw warnings for our own header
  * gsk: fix rectangle drawing using border nodes
  * widget: Fix context menu event check
  * widget: notify of style change upon css_changed
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.75.0:
  * regex: Add out param for error location to the _full() APIs
  * widget: Don't update the ringview before scrolling in history
  * regex: Add API to set extra PCRE2 compile flags
  * widget: Scroll to the bottom on preedit
  * widget: Deprecate old get-text APIs
  * widget: Add bindable replacement API to get the displayed text
  * widget: gtk4: Delay unsetting the context menu to idle
  * widget: Work around kinetic scrolling when changing the adjustment
  * app: Add more scrolling options
  * widget: Add scroll-on-insert property
  * bidi: Use malloced workspace area
  * widget: Fix initial cursor blink state
  * widget: Fix selected text API with block selection mode
  * draw: Remove unused alpha param from drawing methods
  * widget: Add class vfunc for setup-context-menu signal
  * vte: avoid creating rect/region on GTK 4
  * vte: remove extra PTY read from tick callback
  * vte: emit adjustment changed in tick callback
  * Reapply "vte: drive updates from GdkFrameClock"
  * widget: gtk4: Add long press touch gesture
  * lib: Inline the Unicode character width database
  * ring: Fix error handling in the rewrapping code
  * stream: Add debug assertions verifying the snake's integrity
  * stream: Fix a rare corruption when advancing the tail
  * DOAP: Replace defunct mailing list with Discourse support forum
  * Revert "vte: drive updates from GdkFrameClock"
  * widget: Add context menu support
  * draw: Add some constexpr to Rectangle methods
  * widget: Improve yalign docs
  * build: Suppress a warning about an unused variable in non-debug mode
  * lib: Do not initialize cells before inserting characters
  * lib: Fix lines unwrapping too far
  * lib: Speed up inserting runs of ASCII characters
  * lib: Simplify invalidation bounding box tracking
  * emulation: Fix cursor position after an escape sequence initiated resize
  * lib: Remove unnecessary "struct"s
  * emulation: Save/restore along with the cursor whether wrapping will occur
  * emulation: Make ED 2 and EL 2 clear the pending wrap flag
  * emulation: Make DA1 report horizontal scrolling support
  * emulation: Fix ECH not to expand the row beyond the terminal's width
  * emulation: Make DECCOLM and DECALN reset the scrolling region
  * emulation: Adjust Cursor Position Report (CPR) for left and right margins
  * emulation: Implement Forward Index (DECFI) and Back Index (DECBI)
  * emulation: Implement Insert Column (DECIC) and Delete Columnn (DECDC)
  * emulation: Adjust IRM mode for left and right margins
  * emulation: Adjust Insert Character (ICH) and Delete Character (DCH)
  * emulation: Implement Scroll Left (SL) and Scroll Right (SR)
  * emulation: Minor cleanup at smart tab handling
  * emulation: Adjust cursor moving operations to respect left and right margins
  * emulation: Shuffle a few methods to a more logical order
  * emulation: Adjust vertical scrolling to respect left and right margins
  * doc: Add scrolling-region.txt
  * emulation: Adjust cursor tracking and autowrapping for the right margin
  * emulation: Execute SCORC even when DECLRMM is enabled
  * emulation: Track DECSLRM left and right margins
  * emulation: Fix the behavior if invalid scrolling region is requested
  * emulation: Scroll Up (SU) and Delete Line (DL) push to the scrollback
  * emulation: Disregard bce in the scrolling region
  * emulation: Extend vte_scrolling_region to track all four margins
  * emulation: Rename start/end margins to top/bottom
  * emulation: Preserve empty cells as NULs when computing DECRQCRA checksum
  * widget: Remove an unused parameter of get_text()
  * bindings: vala: Depend on graphene-gobject-1.0
  * build: Silence deprecation warnings
  * drawing-gsk: fix a potential crash with empty runs
  * vte: drive updates from GdkFrameClock
  * emulation: Also use invisible bit for DECRQCRA checksum
  * emulation: Correct DECRQCRA negation
  * emulation: make DECRQCRA behave as VT520
  * parser: modes: Additions from recent xterm
  * build: Fix compile in debug mode
  * debug: use vte_assert_cmp* functions
  * bidi: reuse char and index arrays across runs
  * terminal: require caller to allocate GString for get_text()
  * vteinternal: use specialized array for char attributes
  * draw: minifont: Only pad character where necessary
  * draw: minifont: Fix drawing of diagonals
  * draw: Style fixes
  * draw: Include drawing-context.hh not drawing-cairo.hh
  * draw: Use a named constant
  * draw: implement native GTK 4 drawing
  * draw:minifont: Add comment to the LR and RL hatching patterns
  * Update Greek translation
  * minifont: remove unused attr parameter
  * vtetypes: add GdkRGBA conversion utility
  * app: avoid using Cairo fallback nodes on GTK 4
  * build: bump GTK requirement to 4.12
  * draw: minifont: Fix lr/rl hatching pattern to tile seamlessly
  * vte: batch printable character insertion
  * parser: move vte_parser_t into vte::parser::Parser
  * rowdata: use std::fill_n()
  * build: Fix the build with sixel enabled
  * ring, fonts: use g_string_truncate() to reset string
  * build: compile out assertions and cast-checks
  * ring: remove VteRing C wrapper for vte::base::Ring
  * ring: inline vte::base::Ring::index_writable()
  * ring: inline vte::base::Ring::ensure_writable()
  * unistr: fix typo in gtk-doc
  * utf8: Add some more tests
  * unistr: inline unichar into GString as UTF-8
  * unichar: hoist common unichar width into caller
  * stream: switch compression from zlib to LZ4
  * unistr: hoist _vte_unistr_strlen() into caller
  * unistr: hoist g_string_append_unichar() into caller
  * bidi: add VteBidiIndexes array using GdkArrayImpl
  * bidi: add VteBidiChars array of gunichar
  * import GdkArrayImpl for fast arrays
  * build-aux: add flatpak manifest for testing from Builder
  * ci: Only upload docs for tags
  * Revert "widget: a11y: Add missing text changes on scrolling with modifications"
  * Revert "widget: a11y: Optimize text changes on scrolling with modifications"
  * widget: VteTerminalSpawnAsyncCallback's error is nullable
  * widget: a11y: Optimize text changes on scrolling with modifications
  * widget: Fix conditional
  * widget: Fix conditional
  * app: Correct option value description
  * Revert "widget: Do not count event as handled in more situations"
  * test: Add SGR 4:4 and 4:5 underlines to test script
  * emulation: Ignore unknown SGR underline subparams
  * widget: Correct "Since:" annotations
  * lib: Fix preallocated size
- Add pkgconfig(liblz4) BuildRequires: new dependency.
* Sun Jan 14 2024 Yifan Jiang <yfjiang@suse.com>
- Provide and Obsolete old typelib-1_0-Vte-2.91 package whose
  %%{_binver} used the same exact value as %%{_apiver}.
* Tue Dec 19 2023 dimstar@opensuse.org
- Update to version 0.74.2:
  * lib,bidi: Work on the heap rather than the stack
  * stream: Fix a rare corruption when advancing the tail
  * widget: Fix initial cursor blink state
  * build: Post release version bump
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Tue Nov 14 2023 Daike Yu <yu.daike@suse.com>
- Update vte-revert-back-to-c++17.patch
  * revert more C++20 features
* Sat Oct 21 2023 bjorn.lie@gmail.com
- Update to version 0.74.1:
  * ci: Only upload docs for tags
  * widget: VteTerminalSpawnAsyncCallback's error is nullable
  * Updated translations.
- Drop f1a547f1dfebd8860021b6b727fa5d5717e9f143.patch: fixed
  upstream.
* Wed Oct  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add f1a547f1dfebd8860021b6b727fa5d5717e9f143.patch: widget:
  VteTerminalSpawnAsyncCallback's error is nullable. Fixes:
  https://gitlab.gnome.org/GNOME/vte/-/issues/2647
* Sun Sep 17 2023 bjorn.lie@gmail.com
- Update to version 0.74.0:
  * widget: Fix conditional
  * app: Correct option value description
  * build: Post release version bump
  * Revert "widget: a11y: Add missing text changes on scrolling
    with modifications"
  * Revert "widget: Do not count event as handled in more
    situations"
  * test: Add SGR 4:4 and 4:5 underlines to test script
  * emulation: Ignore unknown SGR underline subparams
  * lib: Fix preallocated size
  * Updated translations.
- Change compression in service and tarball produced to zst.
* Sun Sep  3 2023 bjorn.lie@gmail.com
- Update to version 0.73.99:
  * Revert "widget: a11y: Add missing text changes on scrolling
    with modifications"
  * Revert "widget: Do not count event as handled in more
    situations"
  * test: Add SGR 4:4 and 4:5 underlines to test script
  * emulation: Ignore unknown SGR underline subparams
  * Update Turkish translation
  * lib: Fix preallocated size
* Sun Aug  6 2023 bjorn.lie@gmail.com
- Update to version 0.73.93:
  * all:
  - Remove SIXEL support from stable branch
  - Use defined values for defines
  - Use __has_include
  * build:
  - Enable gtk4 by default
  - More detailed version info
  - Post release version bump
  * docs: Publish as gitlab pages
  * draw: Remove need to generate code
  * emulation:
  - Fix infinite loop on non-number OSC 104 param
  - Fix invalid mouse scroll event on window edge
  - Treat unsupported SGR 4:n as no-underline
  * fonts:
  - Don't declare this inline
  - Keep layout text available for cairo
  - Keep the PangoLayout unchanged
  - Remove unnecessary context change call
  * pty:
  - Do not typecast to GSpawnFlags
  - Fix exit delay in presence of a grandchild process
  - Make netbsd workaround conditional on kernel version
  * Revert "widget: Modernise HTML output"
  * widget:
  - a11y: Add missing text changes on scrolling with
    modifications
  - Add API to override font options
  - Defer alignment API to next cycle
  - Do not count event as handled in more situations
  - Do not possibly deny early click gesture
  - Don't consume right clicks on gtk4
  - Don't consume right clicks on gtk4
  - Ensure the ringview is updated before converting coordinates
  - Fix a deprecation warning
  - Fix compilation
  - Fix cursor blink timeout
  - Fix introspection annotations
  - Fix introspection API
  - Fix introspection warnings
  - Fix setting clipboard with html data
  - gtk4: Hint and quantize font metrics
  - Invalidate ringview when the invalidating
  - Make get_text_range docs more accurate
  - More docs and introspection annotation fixes
  - Update some Since annotations
  + Updated translations.
* Mon Jun  5 2023 bjorn.lie@gmail.com
- Update to version 0.72.2:
  * emulation: Fix infinite loop on non-number OSC 104 param
  * widget: Don't consume right clicks on gtk4
- Drop 24547fb3.patch: Fixed upstream.
* Tue May  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 24547fb3.patch: widget: Don't consume right clicks on gtk4.
* Sun Apr 16 2023 bjorn.lie@gmail.com
- Update to version 0.72.1:
  + emulation: Fix invalid mouse scroll event on window edge
  + widget:
  - Fix compilation
  - Fix setting clipboard with html data
  - Fix introspection warnings
  - Fix cursor blink timeout
  + Updated translations.
* Mon Mar 20 2023 bjorn.lie@gmail.com
- Update to version 0.72.0:
  + fonts:
  - Keep the PangoLayout unchanged
  - Keep layout text available for cairo
* Mon Mar  6 2023 bjorn.lie@gmail.com
- Update to version 0.71.99:
  + pty: Do not typecast to GSpawnFlags
  + fonts: Remove unnecessary context change call
  + widget:
  - Fix a deprecation warning
  - gtk4: Hint and quantize font metrics
  - Fix introspection API
  - Don't consume right clicks on gtk4
* Sun Feb 26 2023 bjorn.lie@gmail.com
- Update to version 0.71.92:
  + all: Remove SIXEL support from stable branch
  + app:
  - Disconnect signal handlers on dispose
  - Filter unwanted environment variables
  + build:
  - Add define for darwin
  - Add define for openbsd
  - Fix netbsd define
  - Print warning on unstable release
  - Update meson req version
  + lib:
  - Add gresources to vte/gtk4
  - Fix spawning on netbsd
  + missing: Add better fdwalk implementation for darawin
  + parser:
  - Add more OSC codes
  - modes: Mark modes that should not be reset by DECSTR
  - Update list of known OSC codes
  + pty:
  - netbsd fix
  - Remove useless setenv calls
  + widget:
  - Add API to get text as HTML
  - clipboard: Add missing else
  - Clipboard fixes for gtk4
  - Defer alignment API to next cycle
  - Ensure the ringview is updated before converting coordinates
  - Fix value type check
  - Fix Widget::regex_match_check_at()
  - gtk4:
    . Don't grab the focus on focus-in
    . Only notify terminal when focused
    . Translate control+key events when using multiple layouts
  - Implement clipboard for gtk4
  - Modernise HTML output
  - Offer text/html also in UTF-8 format
  - Use correct end row for getting the selected text
  - Use correct view coordinates
  + Updated translations.
- Rebase vte-enable-build-flag-pie.patch with quilt.
* Tue Feb 14 2023 bjorn.lie@gmail.com
- Update to version 0.70.3:
  + widget:
  - Ensure the ringview is updated before converting coordinates
  - gtk4: Translate control+key events when using multiple
    layouts
  - Use correct end row for getting the selected text
- Drop ddb2c8a.patch: Fixed upstream.
* Thu Jan 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add ddb2c8a.patch: widget: Use correct end row for getting the
  selected text. The range is end-exclusive, so use end_row()
  instead of last_row(). Fixes glgo#GNOME/vte#2584
* Mon Dec  5 2022 dimstar@opensuse.org
- Update to version 0.70.2:
  * widget: Modernise HTML output.
  * missing: Add better fdwalk implementation for darawin.
  * build: Print warning on unstable release.
  * build: Add define for openbsd.
  * Updated translations.
* Thu Oct 27 2022 bjorn.lie@gmail.com
- Update to version 0.70.1:
  + app:
  - Disconnect signal handlers on dispose.
  - Filter unwanted environment variables.
  + build:
  - Add define for darwin.
  - Fix netbsd define.
  + widget:
  - Don't consume right clicks on gtk4.
  - Implement clipboard for gtk4.
  * Updated translations.
* Fri Sep 16 2022 bjorn.lie@gmail.com
- Update to version 0.70.0:
  + build: Post release version bump
* Sun Sep  4 2022 bjorn.lie@gmail.com
- Update to version 0.69.99:
  + build: Version 0.69.99 for gnome 43rc
  + lib: Fix spawning on netbsd
  + widget:
  - Fix Widget::regex_match_check_at()
  - Use correct view coordinates
  - gtk4:
    . Only notify terminal when focused
    . Don't grab the focus on focus-in
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Disable glade catalog support via bcond.
- Fixup the defines, most importantly name the vte typelib
  correctly again.
* Tue Aug  9 2022 bjorn.lie@gmail.com
- Update to version 0.69.92:
  + all:
  - Include <termios.h> directly
  - Remove SIXEL support from stable branch
  - Don't override widget's CSS names
  + bindings:
  - gir: Change vte/gtk4 gir nsversion
  - vala:
    . Add vapi for vte/gtk4
    . Remove the test app
  + build:
  - Also set _XOPEN_SOURCE
  - Build fix for netbsd
  - Bump meson req version to 0.51
  - Check for python version
  - Define __BSD_VISIBLE on freebsd
  - Define list of libc feature test macros only once
  - Fix debug build
  - Make sure __BSD_VISIBLE is defined on freebsd
  - Remove gtk4 notice
  - Try to fix pwrite detection on non-glibc systems
  - Update gtk3 req version
  - Use an explict python interpreter
  + docs:
  - Install toml file to subdir
  - Port to gi-docgen
  + fonts:
  - gtk4: Create a new pango context
  - Only set language if different to the current language
  - Pass nullptr for language
  + glib:
  - glue:
    . Include string
    . Include string_view
  + lib:
  - Fix reserved size calculation
  - Move glib glue code to glib-glue.cc
  + Revert "emulation: Support XTVERSION sequence"
  + sixel: Remove stray semicolon
  + spawn: Fix build without CLOSE_RANGE_CLOEXEC
  + widget:
  - Add API to get selected text
  - widget: Add format arg to new API to get selected text
  - Correct some Since annotations
  - Defer alignment API to next cycle
  - Don't queue_resize() during allocation
  - Fix padding borders
  - Fix some API version tags
  - gtk4:
    . Add API to check event context
    . Don't invalidate endlessly
    . Lower the priority of the style provider
    . Make background API available on gtk4
    . Simplify invalidation tracking
  - gtk: Make new API naming self-consistent
  - Ignore synthetic scroll events
  - Listen for toplevel focus change
  - Only avoid reentrant queue_resize() in GTK4
  - Queue a resize on CSS changes
  - Remove errneous gtk_widget_allocate call
  + Update translations.
- Rebase vte-enable-build-flag-pie.patch with quilt.
- Set bcond to without, build gtk4 support.
- Drop gtk-doc and add pkgconfig(gi-docgen) BuildRequires following
  upstreams port to gi-docgen.
* Sun Mar 27 2022 bjorn.lie@gmail.com
- Update to version 0.68.0:
  + spawn: Fix build without CLOSE_RANGE_CLOEXEC
  + Revert "emulation: Support XTVERSION sequence"
* Sat Feb 12 2022 bjorn.lie@gmail.com
- Update to version 0.67.90:
  + widget:
  - Defer alignment API to next cycle
  - Deprecate VteCharAttributes struct
  - Deprecate the attributes out-param for vte_terminal_get_text
  - Fix measure baseline to return -1
  + all: Remove SIXEL support from stable branch
  + sixel: Fix DECGRI for parameter value 0
  + build:
  - Change gtk4 GIR version hack
  - Assert on non-supported option on stable branch
  + lib: Remove misplaced inline from function declaration
  + emulation: Support XTVERSION sequence
  + parser: Fix comments
  + fonts: Fix height check
  + Updated translations.
- Disable gtk4 support via bcond. Upstream did not move forward
  with this support for now.
* Thu Dec 30 2021 bjorn.lie@gmail.com
- Update to version 0.66.90+git.e32dba1:
  + build:
  - Fix check for -fstack-protector* compiler support
  - Rework function checks
  - Fix build with kernel headers from linux < 4.13
  + app:
  - Fix context menu styling
  - Improve option value description
  - Add option to set initial title
  + widget:
  - Split alignment and fill properties
  - Fix Since version for new API
  - Add vte_terminal_paste
  - Add more precondition checks for vte_pty_spawn_async_with_fds
  - Correct some API Since: versions
  - Adjust preedit position to GtkEntry
  + vala:
  - Reference of [GtkChild] field is handled by GtkBuilder, type
    must be unowned
  - Fix accessibility of constant intializer expression
  + terminal:
  - Make CRLF pastification smarter
  - Make pastification not replace something with nothing
  - Add tests for text paste transformation
  + parser:
  - Fix some control codes
  - Recognise more commands
  - modes: Fix DECSDM default value
  + lib:
  - Check for close_range function and use it when available
  - ABI repairs
  + emulation:
  - ECMA modes should not be saved by DECSC
  - Use correct range for DECRQCRA
  - Docs improvements
  - Fix xterm window size request response
  + fonts:
  - Relax font sanitisation
  - Improve font bolding
  - More metrics sanity checks
  + vte.sh: Fix the check for PROMPT_COMMAND when it is unset
  + docs: Add index for API new in 0.68
  + vte.sh: Use PROMPT_COMMAND as an array when possible
  + spawn: FD reassignment code tweaks
  + Updated translations.
- Add pkgconfig(gtk4) BuildRequires and pass gtk4=true to meson,
  build gtk4 widgets. Following this, add new sub-packages
  typelib-1_0-Vte-2.91-gtk4 and vte-tools-gtk4.
* Sat Dec  4 2021 bjorn.lie@gmail.com
- Update to version 0.66.2:
  + parser: Fix some control codes
  + emulation:
  - ECMA modes should not be saved by DECSC
  - Use correct range for DECRQCRA
* Sat Oct 30 2021 bjorn.lie@gmail.com
- Update to version 0.66.1:
  + app: Add option to set initial title
  + vte.sh: Fix the check for PROMPT_COMMAND when it is unset
  + Updated translations.
- Drop vte-silence-COMMAND_PROMPT.patch: Fixed upstream.
* Wed Oct 27 2021 Daike Yu <yu.daike@suse.com>
- Add vte-revert-back-to-c++17.patch
  revert c++20 features back to c++17 to build on SLE/Leap
* Fri Sep 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add vte-silence-COMMAND_PROMPT.patch: Silence warning when
  opening terminal about PROMPT_COMMAND being an unknown command.
* Wed Sep 22 2021 bjorn.lie@gmail.com
- Update to version 0.66.0:
  + emulation: Fix xterm window size request response.
  + widget: Adjust preedit position to GtkEntry.
  + vte.sh: Use PROMPT_COMMAND as an array when possible.
  + fonts: More metrics sanity checks.
  + Update translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Aug 24 2021 dimstar@opensuse.org
- Update to version 0.65.91:
  + Port to GTK 4.
  + all: Remove SIXEL support from stable branch
  + app: Add debug option to track clipboard targets
  + app: Add option to use a GtkScrolledWindow
  + lib: Fix switching encodings
  + parser: Add new OSC command from xterm 367
  + parser: Recognise more commands
  + sixel: Fix pixel aspect calculation
  + sixel: Remove ununused tracking of palette modification
  + sixel: Reset repeat counter when receiving the next command
  + widget: Add API to make adjustment values pixels
  + Updated translations.
* Mon Aug  9 2021 Yifan Jiang <yfjiang@suse.com>
- BuildRequires python3-dataclasses since SLE 15.4 uses python36
  to build.
* Wed Jul 28 2021 Yifan Jiang <yfjiang@suse.com>
- Add vte-enable-build-flag-pie.patch: enable PIE flag to be
  compatible with gcc default linking option. Otherwise build will
  be failed with current SLE-15-SP4 project setup.
* Mon Jun  7 2021 bjorn.lie@gmail.com
- Update to version 0.64.2:
  + widget: Docs fix
  + Updated translations.
* Fri May 14 2021 dimstar@opensuse.org
- Update to version 0.64.1:
  + widget: Move clipboard store from finalize to unrealize.
  + build: Work around a meson bug with dist scripts in
    subprojects.
  + build: Add missing includes.
* Sat Apr 17 2021 dimstar@opensuse.org
- Update to version 0.64.0:
  + app: Add debug option to track clipboard targets.
  + parser: Add new sequence from xterm 362.
  + pty: Add support for PTY packet mode on sysv-like systems.
  + app: Fix search next/prev button sensitivity.
  + app: Use smart pointer.
  + app: Fix background image drawing.
  + emulation: sixel: Implement DECSET 1070.
  + vte.sh: Avoid warnings if shell is configured with 'set -u'.
* Sat Apr 17 2021 dimstar@opensuse.org
- Update to version 0.62.1:
  + Export vte_pty_spawn_finish again.
  + Post release version bump.
  + docs: Remove three mistaken little words.
  + gtk: Allow passing null callback to spawn_async.
  + lib: Abort when alloc returns nullptr.
  + parser: HTJ is not a NOP.
  + pty: Allow null callback for spawn_async.
  + vte.sh: Avoid warnings if shell is configured with 'set -u'.
  + widget: Define text_view_bg in fallback CSS if the theme
    doesn't.
  + widget: Implement GtkScrollableInterface::get_border.
  + widget: Reference terminals while processing.
  + Updated translations.
* Sun Feb 14 2021 gmbr3@opensuse.org
- Update to version 0.63.91:
  + all: Remove SIXEL support from stable branch.
  + lib: Replace deprecated std::is_pod.
  + parser:
  - DECBI is NOP.
  - Add new sequence from xterm 362.
  - Properly refer to python3.
  + docs: Add index for API new in 0.64.
  + build:
  - Fix build.
  - Add config.h as dependency to all sources.
  - Restore glade catalogue.
  + app: Fork UI files for gtk3.
  + widget:
  - Use GdkEvent accessor function.
  - Implement GtkScrollableInterface::get_border.
  + Updated translations.
- Changes for the restored glade catalogs:
  + Add glade BuildRequires.
  + Split out new glade-catalog-vte.
* Sun Feb 14 2021 bjorn.lie@gmail.com
- Update to version 0.62.3:
  + keymap: Use int8_t for the length of the short keymap strings
  + Revert "lib: Sanitise the passed-in font description"
  + Updated translations.
* Sat Jan  9 2021 bjorn.lie@gmail.com
- Update to version 0.62.2:
  + widget:
  - Limit select-all to the writable region not including the
    scrollback
  - Fix idle child-exited signal after dispose
  + app:
  - Fix search next/prev button sensitivity
  - Fix background image drawing
  + lib:
  - desc is not a smart pointer in 0.62
  - Fix unused variable warning when not using getrlimit
  - Use sysconf on macos to get the upper limit of number of FDs
  - Sanitise the passed-in font description
  - Add missing nullable annotation to spawn child setup
    functions
* Tue Oct  6 2020 dimstar@opensuse.org
- Update to version 0.62.1:
  + widget: Implement GtkScrollableInterface::get_border.
  + widget: Reference terminals while processing.
  + pty: Allow null callback for spawn_async.
  + gtk: Allow passing null callback to spawn_async.
  + lib: Abort when alloc returns nullptr.
  + vte.sh: Avoid warnings if shell is configured with 'set -u'.
  + widget: Define text_view_bg in fallback CSS if the theme
    doesn't.
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 0.62.0:
  + Export vte_pty_spawn_finish again.
  + docs: Remove three mistaken little words.
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 0.61.91:
  + parser: HTJ is not a NOP.
  + Revert "all: Add SIXEL support".
  + all: Fix sixelparser.{hh,cc} licence header.
  + pty: Only fill in ws_[xy]pixel when sixel is enabled.
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 0.61.90:
  + app: Add options to use theme colours.
  + bindings: gir: Add missing file to extract source comments and
    annotations from.
  + lib: Fix the build with debug disabled.
  + lib: Improve exception error message without debug enabled.
  + spawn: Check for explicit systemd requirement.
  + spawn: Don't change PWD when no cwd is given.
  + systemd: Place vte into app.slice rather than apps.slice.
  + vte.csh: Fix the behavior if VTE_VERSION is undefined.
* Fri May 29 2020 bjorn.lie@gmail.com
- Update to version 0.60.3:
  * widget:
  - Fix underlining the space character in a matched regex
  - Notify correct property when setting the scroll-on-keystroke
  - Set error from vte_terminal_set_encoding when built without
    ICU
  * pty: Call grantpt/unlockpt when opening the PTY
  * icu: glue: Set error callback on the from-unicode conversion
  * lib: Fix switching between legacy encodings
  * all: Fix the build without ICU
  * docs: Add index for API new in 0.60
* Sun Apr 26 2020 bjorn.lie@gmail.com
- Update to version 0.60.2:
  * icu: glue: Set error callback on the from-unicode conversion
  * lib: Fix switching between legacy encodings
  * widget: Set error from vte_terminal_set_encoding when built
    without ICU
  * all: Fix the build without ICU
  * docs: Add index for API new in 0.60
  * lib: Fix exception thrown from std::clamp
  * pty: spawn: Reap the child process if the systemd call fails
  * docs: Add regex flag requirements
  * bindings: gir: Add missing file to extract source comments and
    annotations from
  * build: Post release version bump
* Fri Mar 27 2020 bjorn.lie@gmail.com
- Update to version 0.60.1:
  * widget: Emit the ::commit signal even when the terminal has no
    PTY.
  * bindings: gir: Fix VtePty.
  * vte.csh: Fix the behavior if VTE_VERSION is undefined.
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 0.60.0:
  * Updated translations.
* Sat Feb 29 2020 bjorn.lie@gmail.com
- Update to version 0.59.92:
  * app: Add option to disable scrollbar.
  * build: systemd: Add option to disable systemd support.
  * draw:
  - Enable unicode 13 legacy terminal characters.
  - Add extra define for separated mosaic drawing.
  * emulation: Remove 'separated mosaic' SGR.
  * lib: Use g_propagate_error here.
  * Updated translations.
* Sat Feb 15 2020 bjorn.lie@gmail.com
- Update to version 0.59.91:
  * pty:
  - Reduce wait-for-EOS time to 2 seconds
  - Document VTE_SPAWN_NO_PARENT_ENVV
  - Fix indefinite wait for EOS after child-exited
  - Add debug output for when EOS happens
  - Cleanup session creation
  - Add more error checking
  - Start new session before opening the PTY peer
  - Separate PTY code from its GObject wrapper
  - Set size on creation
  * build:
  - Fix libsystemd req version
  - Suppress warnings about ignored returned value
  - Remove unncessary feature test
  - Remove unnecessary feature test for functions
  - Add configure switch to disable a11y code
  - Ensure LTO is off
  - Add option to disable -Bsymbolic-functions
  - Add no-exceptions sanity check
  * systemd:
  - Put child process into the parent's slice
  - Install config drop-in for vte-spawn-.scope
  - Add systemd support
  * lib:
  - Add smart pointer for g_free()able things
  - Add missing noexcept
  - Use Timer class for mouse autoscroll timer
  - Use Timer class for text blink timer
  - Use Timer class for cursor blink timer
  - Add convenience class for timeouts
  - Add GError convenience class
  - Add missing files
  - Rework child exit and EOF handling
  - Use ICU for legacy charset support
  - Typo fix
  - Remove GIOChannel use
  * emulation:
  - Remove support for obsolete charset
  - Remove support for window control sequences
  - Report fixed origin for CSI 13 t
  - Maintain cursor column during screen switch
  - Ignore delete/insert line outside the scroll region
  - Fix vertical cursor movememnt outside the scroll region
  * vte.sh:
  - Add vte.csh, a tcsh counterpart of vte.sh
  - Use the vte-urlencode utility
  - Remove the obsolete __vte_ps1 function
  * prompt:
  - Add a test for the vte-urlencode-cwd utility
  - Add a vte-urlencode-cwd utility
  * widget:
  - Set terminal input purpose
  - Finish deprecation of GRegex taking APIs
  - Add missing (nullable) annotations
  - Emit EOF signal from idle handler
  - Fix crash using nullptr for word char exceptions
  - Move some calls to Widget constructor
  - Move scrollable adjustments up to Widget
  - Deprecate vte_terminal_feed_child_binary
  * regex:
  - Use string_view and optional
  - Use string_view
  * parser:
  - Small documentation addition
  - Make unused command a NOP
  * draw:
  - Fix unused function warning
  - Use functions instead of macros
  - Make some data static and shrink it
  - Narrow the range of characters in the U+1FBxx block
  - Implement U+1FBAF
  - Improve diagnoals drawing
  - Make new diagonal characters align better with box drawings
  - Use binary notation for some constants
  - Change checkboard pattern
  - Implement hatching pattern characters U+1FB98 and U+1FB99
  - Implement separated mosaic graphics
  - Add manual drawing for new legacy terminal unicode characters
  - Fix reporting the dimensions of locally drawn graphic
    characters
  * terminal:
  - Don't append data to sealed chunks
  - Use smart pointer
  - Use string_view
  - Skip commit signal emission when there are no handlers
  - Remove some incorrect doc comments
  - Remove redundant function
  - Use an enum class for selection type
  - Move enums used in only one file into it
  - Use an enum class for mouse tracking mode
  - Remove unused enum
  - Remove double-initialisation
  - Use an enum class for erase bindings
  - Store word chars exceptions string in Widget
  - Use an enum class for text blink mode
  - Use an enum class for cursor shape
  - Use an enum class for cursor blink mode
  - Use an enum class for cursor style
  - Move some initialisations to the class
  - Remove extraneous fcntl
  * introspection: Fix signedness in vte_terminal_feed_child's
    annotation.
  * test:
  - Add some more explanation to the UTF-8-test.txt file
  - Document the changes made to UTF-8-test.txt
  - Add UTF-8 test
  * git: Diff *.txt files as text
  * debug: Handle all enum values in switch
  * spawn: Warn if G_SPAWN_LEAVE_DESCRIPTORS_OPEN is passed
  * fixup pty gobject
  * Updated translations.
- Add pkgconfig(libsystemd) BuildRequires: New dependency.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 0.59.0:
  * emulation:
  - Ensure the cursor remains onscreen when moving down.
  - Make DEC alternate charset convert underscore to space.
  - Remove SRM support.
  - Remove urxvt mouse extension support.
  * lib: Rework how vte stores the match and search regexes.
  * pty: Fix error check for ioctl(TIOCGPTPEER) failure.
  * regex: Add missing noexcept.
  * regex: Make regex a C++ class.
  * ring: Fix an incorrect assertion.
  * ring: Tiny code cleanup: maintain GString integrity.
  * spawn: Port fdwalk improvements from glib.
  * widget: Deprecate vte_terminal_[sg]et_allow_bold().
  * widget: Don't scroll to bottom on keystroke in read-only mode.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Nov 23 2019 bjorn.lie@gmail.com
- Update to version 0.58.3:
  + emulation:
  - Report fixed origin for CSI 13 t.
  - Maintain cursor column during screen switch.
  - Ignore delete/insert line outside the scroll region.
  - Fix vertical cursor movememnt outside the scroll region.
  + pty: Set size on creation.
  + build: Add no-exceptions sanity check.
  + Updated translations.
* Mon Nov 18 2019 Frederic Crozat <fcrozat@suse.com>
- Add explicit BuildRequires pkgconfig(fribidi) >= 1.0.0.
- Add minimal version for pcre2 BuildRequires.
* Fri Oct 11 2019 bjorn.lie@gmail.com
- Update to version 0.58.2:
  + ring: Fix an incorrect assertion.
  + pty: Fix error check for ioctl(TIOCGPTPEER) failure.
* Mon Oct  7 2019 bjorn.lie@gmail.com
- Update to version 0.58.1:
  + emulation: Ensure the cursor remains onscreen when moving down.
  + widget: Don't scroll to bottom on keystroke in read-only mode.
  + Updated translations.
* Mon Sep  9 2019 bjorn.lie@gmail.com
- Update to version 0.58.0:
  + build: Don't pass C warning flags to the C++ compiler.
- Update URL to point to gitlab home.
* Sun Aug 11 2019 bjorn.lie@gmail.com
- Update to version 0.57.90:
  + draw: #include <algorithm> for std::max
  + pty: Prefer using TIOCGPTPEER ioctl
  + pty: Use O_NOCTTY when VTE_PTY_NOCTTY is set
  + bidi: Disable Arabic ligatures
  + Updated translations.
- Changes from version 0.57.3:
  + Add barebones README
  + all: Add installation & debugging information
  + app: Plug mem leaks
  + bidi:
  - Add API to enable or disable bidirectional text support
  - Find the BiDi mapping for the RingView's contents
  + build:
  - Add debug flags when debug is enabled
  - Add missing file
  - Check gcc version
  - Do not allow disabling asserts
  - Fix build on meson 0.49
  - Ignore everything in the build directory
  - Increase test timeout
  - List Wextra warnings
  - Port to meson build system
  - Use our own warning flags
  + docs:
  - Add index for API new in 0.56
  - Add index for API new in 0.58
  + docs,bidi: Clarify the relation between get_text API methods
    and BiDi
  + draw:
  - Align the baseline across font styles
  - Measure characters individually
  - Optimise invalidation and painting
  + emulation,bidi: Add keyboard swapping mode
  + emulation:
  - Fix background color handling of DCH and ECH
  - Improve docs
  - Make certain operataions convert line endings to hard newline
  - Track BiDi parameters
  + gir: Fix introspection annotations
  + l10n:
  - Add POTFILES.skip back
  - Re-rename POTFILES to POTFILES.in
  + mev: Fix an implicit fallthrough warning
  + parser: glue: Correct parameter collection
  + perf,bidi: Add BiDi demo and info files
  + pty: Make vte_pty_child_setup() useful for flatpack
  + reflect: Fix compiler warnings
  + regex: Fix doc comment
  + Revert "parser: glue: Use std::clamp"
  + ring:
  - fix printf format
  - Keep an additional row writable
  - Silence some warnings with debug disabled
  + ringview: Add RingView infrastructure
  + vala:
  - Make binding tests compile without warning
  - Make the vala test build without warnings
  + vte.sh: Remove control chars for window title
  + widget:
  - Add valist signal marshallers
  + widget: Avoid double painting of letters
  - Cancel autoscroll on ending selecting
  - Clean up invalidating in insert_char()
  - Deprecate vte_terminal_[sg]et_rewrap_on_resize()
  - Don't clamp before invalidating from process_incoming()
  - Find contiguous LTR and RTL runs of decoration
  - Fix invalidation with scrolling region
  - Fix misleading comments in cursor_down()
  - Increase minimum width to 2 cells plus padding
  - Invalidate the entire paragraph when its contents change
  - Merge identical m_color_defaults and m_fill_defaults
  - Move out a common condition for painting the background
  - Refactor offscreen cursor detection
  - Remove line_is_wrappable()
  - Revert to paint unused rows
  - Set the soft_wrapped flag via wrapper methods
  - Throw away remaining incoming data on finalize
  + widget,bidi:
  - Denote the direction in the I-beam cursor
  - Display according to the BiDi mapping
- Add meson BuildRequires and macro following upstreams port.
- Drop gnome-common BuildRequires and autogen call, no longer
  needed with meson buildsystem.
* Sat Aug 10 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop the glade catalog subpackage. The catalogue is unmaintained
  and has been dropped upstream with version 0.57.1.
  This has the nice side effect of removing an indirect build
  dependency on webkit2gtk3 via glade.
* Mon May  6 2019 bjorn.lie@gmail.com
- Update to version 0.56.3:
  + widget: Avoid double painting of letters.
  + app: Plug mem leaks.
  + widget: Throw away remaining incoming data on finalize.
  + docs: Add index for API new in 0.56.
* Wed Apr 24 2019 bjorn.lie@gmail.com
- Update to version 0.56.2:
  + parser: glue: Correct parameter collection.
  + Revert "parser: glue: Use std::clamp".
* Tue Apr  9 2019 bjorn.lie@gmail.com
- Update to version 0.56.1:
  + widget: Cancel autoscroll on ending selecting.
* Tue Mar 12 2019 bjorn.lie@gmail.com
- Update to version 0.56.0:
  + Stable release version bump.
* Mon Mar  4 2019 bjorn.lie@gmail.com
- Update to version 0.55.92:
  + app: Add fullscreen mode.
  + attr: Typo fix.
  + widget: Prevent clipboard callbacks during destruction.
  + emulation: Do not encode keyboard modifiers in X10 mouse mode.
  + Updated translations.
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 0.55.90:
  + build:
  - Add -Wvla.
  - Use input file as parameter in box drawing script.
  + devanagari.txt: New test file.
  + parser:
  - charset: Mention some more charsets.
  - Document some known deviations from VT100.
  - Assert that the parser is not in an unknown state.
  - Code style fixes.
  - cat: Fix clang build error.
  + perf: Add files to EXTRA_DIST.
  + regex: Add vte_regex_substitute.
  + Replace Bugzilla by Gitlab URL in DOAP file.
  + spawn: Fix g_spawn deadlock in a multi-threaded program on
    linux.
  + vala: Fix build with vala 0.43+ git master due to empty struct
    definition.
  + vteunistr: Add method to concatenate two unistrs.
  + widget:
  - Handle spacing combining marks.
  - Don't show the cursor occasionally over the scrollback data.
  - Disconnect GtkSettings signals in destructor.
  - Fix mouse selection to skip trailing unused cells.
  - Strip off trailing unused cells in get_text().
  - Fix URL recognition after dragging the scrollbar.
- Drop vte-Fix-build-vala-043.patch: Fixed upstream.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 0.55.0:
  + all: Fix implicit-fallthrough warnings
  + app: Add new terminal to main menu
  + build: Require C++17
  + cell: Silence an incorrect warning
  + chunk: Remove erroneous std::move calls
  + conv: Fix crash after multiple encoding changes
  + emulation:
  - Treat rapid blink like blink
  - Make OSC replies with same terminator as request
  - Document two more DECSGR values
  - Document two DEC private ACS value
  - Make dispatch of SCORC symmetrical to SCOSC
  - Implement SCOSC/SCORC
  - Fix upper coordinate limit for legacy mouse events
  + hyperlink-demo.txt: Prefer ST to BEL
  + lib:
  - Fix clang build error
  - Make debug assertion conditional on VTE_DEBUG
  + mev: Add noreturn attribute
  + modes: Use parentheses in macro
  + parser:
  - glue: Use std::clamp
  - charset: Add a DEC private OCS
  - Complete SCI infrastructure
  - Define SGR enum from include files
  - Fix licence template sed job mistake
  - Add another sequence
  - Improve documentation of XTERM_CHECKSUM_MODE
  - Recognise new xterm sequence
  - Remove extraneous sequence
  - Fix incorrect sequence
  - cat:
    . Add linter for SGR sequences
    . Use the parser glue
    . Restructure options parsing
    . Code style fixes
    . Refactor and implement lint mode
  + regex:
  - Check whether PCRE2 was compiled with JIT support
  - Only silence warning on GCC
  - Silence compiler warning
  + ring: Fix thawing combining accents over a double-wide
    character
  + spawn: Add noreturn attribute
  + stream: test: Silence warning
  + tabstops: Cleanup includes
  + tests: Silence unused variable warning
  + utf8:
  - Make decoder conform to recommendation on replacement
    characters
  - Use a symbol for REJECT in the data table
  - Reformat data table
  + vte.sh: Revert to C0 controls in OSC sequences
  + widget:
  - Rewrite the tracking of selection endpoints
  - Convert vte::grid::span to end-exclusive
  - Always invalidate entire rows
  - Always draw entire rows
  - Simplify draw_rows()
  - Deprecate vte_terminal_get_text_include_trailing_spaces()
  - Disable "bold is bright" by default
  - Avoid unnecessary invalidations at hyperlinks
  - Clean up overly complex vte_cell_is_between()
  - Add missing exception specification
  + Updated translations.
- Add vte-Fix-build-vala-043.patch: Fix build with new vala
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 0.54.3:
  + widget:
  - Disconnect GtkSettings signals in destructor.
  - Don't show the cursor occasionally over the scrollback data.
  - Fix URL recognition after dragging the scrollbar.
- Drop patches fixed upstream:
  + vte-widget-Dont-show-cursor-occasionally.patch.
  + vte-widget-Fix-URL-recognition.patch.
* Fri Dec  7 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches:
  + vte-widget-Fix-URL-recognition.patch: widget: Fix URL
    recognition after dragging the scrollbar.
  + vte-widget-Dont-show-cursor-occasionally.patch: widget: Don't
    show the cursor occasionally over the scrollback data.
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 0.54.2:
  + ring: Fix thawing combining accents over a double-wide
    character.
  + emulation:
  - Implement SCOSC/SCORC.
  - Make dispatch of SCORC symmetrical to SCOSC.
  + modes: Use parentheses in macro.
  + widget: Add missing exception specification.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 0.54.1:
  + conv: Fix crash after multiple encoding changes.
  + widget: Avoid unnecessary invalidations at hyperlinks.
  + parser:
  - Remove extraneous sequence.
  - Fix incorrect sequence.
  + vte.sh: Revert to C0 controls in OSC sequences.
  + utf8:
  - Make decoder conform to recommendation on replacement
    characters.
  - Use a symbol for REJECT in the data table.
  + utf8: Reformat data table
  + lib: Make debug assertion conditional on VTE_DEBUG.
  + emulation: Fix upper coordinate limit for legacy mouse events.
  + Updated translations.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 0.54.0:
  + utf8: Don't swallow start bytes in the middle of a sequence.
  + widget: Avoid invalidation from unrealize.
  + emulation:
  - Fix off-by-one in TSR.
  - Be more strict in DECRQSS.
  + Updated translations.
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 0.53.92:
  + emulation:
  - Be more strict in DECRQSS
  - Clarify a comment
  - Add sequence and no-op handler for new xterm SGR functions
  - Add sequence and no-op handler for synchronous update
  + parser: Fix sort order
  + doap: Fix email address
  + widget:
  - Add nullable annotations
  - Always return non-null from vte_terminal_get_encoding
  - Always emit the child-exited signal.
- Switch to gitlab in _service.
* Wed Jun  6 2018 bjorn.lie@gmail.com
- Update to version 0.53.0:
  + all:
  - Fix spelling
  - Cleanup some cruft
  + app: Fix option output in help
  + build:
  - Update requirements
  - Update macros from autoconf-archive
  + cxx:
  - ring: Move to C++
  - Move some headers to .hh
  + docs: Update list of ignored files
  + emulation:
  - Implement DECRQSS
  - Limit window title length
  - Implement OSC 5
  - Implement SUB
  - Implement DECSR
  - Update DA1 response
  - Implement DECRQCRA
  - Fix DECSTBM parameters
  - Refactor tabstop handling
  - Implement the window title stack
  - Remove icon title support
  - Implement DECRQM
  - Use an enum for the XTERM_WM param values
  - Unify mode handling
  - Remove LNM mode support
  - Move sequence handler code directly into the handler
  - Port DECSTBM to new parameter glue
  - Port DL, IL to new parameter glue
  - Port HTS, TBC to new parameter glue
  - Port CBT, CHT to new parameter glue
  - Port REP to new parameter glue
  - Port ICH to new parameter glue
  - Port DCH, ECH to new parameter glue
  - Port CPL, CUU to new parameter glue
  - Port SD, SU to new parameter glue
  - Port CUB, CUF to new parameter glue
  - Port CNL, CUD to new parameter glue
  - Port VPA to new parameter glue
  - Port CHA, HPA, CUP to new parameter glue
  - Port XTERM_WM to new parameter glue
  - Port DECSCUSR to new parameter glue
  - Port DSR to new parameter glue
  + lib:
  - Add RefPtr type for holding a GObject
  - Store preedit string in a string
  - Store word char exceptions in a string
  - Filter out BS and DEL from paste
  - Use an enum for the SGR codes
  + parser:
  - Update copyright notice
  - glue: StringTokeniser must not be used with a temporary
  - Fix warning with GCC < 7
  - Ignore -Wimplicit-fallthrough
  - Remove excessive clearing of sequence fields
  - Only clear the intermediates and params when necessary
  - No need to clear the charset
  - No need to clear for GRAPHIC sequence
  - No need to clear for IGNORE sequence
  - Increase maximum number of parameters
  - Clear only used parameters
  - Remove redundant assignment
  - Ignore sequence with too many parameters
  - Ignore sequence with too many parameters
  - test: Check parameter clearing
  - Annotate unlikely conditionals
  - Add more functions
  - Reject mixed-control OSC and DCS sequences
  - test: Use SequenceBuilder
  - test: Test DCS sequences without intermediates
  - Ignore overflowing OSC and DCS sequences
  - glue: Add wrapper class for struct vte_parser
  - Remove leftover from initial import
  - Distinguish between state changes and actions
  - Simplify parameter parsing
  - Record intermediates in order
  - Don't collect invalid characters in escape sequences
  - Fix typo
  - Ignore most C0 controls in OSC string
  - Speed up no-op strings
  - Ignore DEL in all states
  - Accept C0 ST to terminate OSC, DCS
  - Implement SCI parsing
  - glue: Add sequence builder
  - Implement DCS parsing
  - Remove leftovers from old parser
  - Implement OSC parsing
  - glue: Add some convenience function to collect parameters
  - Improve glue for subparameters
  - cat: Add benchmark mode
  - Improve test programme
  - Parse subparameters in CSI sequences
  - Use 0 as the default arg value
  - Fix charset detection
  - Define a type for CSI parameters
  - Don't clear state when executing a control character
  - Import new parser
  + Revert "emulation: Implement DECRQCRA"
  + ring: Proper boundary checking for hyperlink position
  - Replace some assertions with static_assert
  - Split cell and rowdata headers
  - Add some static assertions
  - Move some types to ring.cc
  - Silence -Wunsafe-loop-optimizations
  + vte.sh: Use C1 controls in OSC sequences
  + widget:
  - Remove GdkVisibilityState handling
  - Use RefPtr for the cursors
  - Remove extraneous refresh-window emissions
  - Deprecate vte_terminal_match_set_cursor_type
  - Remove faux bold support
  - Do not extend the background under faux bold characters
- Update License tag following upstream changes.
* Mon May 21 2018 bjorn.lie@gmail.com
- Update to version 0.52.2:
  + all: Fix spelling.
  + ring: Proper boundary checking for hyperlink position.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 0.52.1:
  + lib: Filter out BS and DEL from paste.
  + widget: Remove GdkVisibilityState handling.
  + emulation: Add support for OSC 5;0 (bold color).
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 0.52.0:
  + build: Post release version bump
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 0.51.92:
  + app: Add option to disable bold.
  + app: Unset env var when not in test mode.
  + draw: Do not cache ligatured glyphs.
  + emulation: Implement DECRQCRA.
  + introspection: Fix annotation for vte_terminal_feed_child.
  + widget:
  - Cleanup integer vs. boolean around faux bold.
  - Do not scroll to the bottom on soft reset.
  - Fix bell timestamp update.
  - Fix disabling bold effect.
  - Fix the initial belief whether the mouse is over the widget.
  - Improve regex and hyperlink highlight tracking.
  - Initialize the last mouse coordinates to the padding.
  - Limit bell rate.
  - No longer generate bold color automatically.
  - Preserve the selection on reset.
  - Protect fudge_pango_colors() against all-inclusive
    PangoAttributes.
  - Unset hyperlink URI when moving the mouse to a non-hyperlink
    cell.
  - Update adjustment page size and increments asynchronously.
  - Update the last mouse coordinates on enter and leave events.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.51.90:
  + all: Rearrange VteCellAttr to store all colours together in one
    uint64_t.
  + app: Uppercase initial for menu entry.
  + emulation: Use deco colour also for default colour and fill
    attributes.
  + pty: spawn: Set PWD to the working directory to preserve
    symlinks.
  + ring: Store cell attributes together in an uint32_t.
  + widget: Add API to not clear the background.
  + widget: Allow regexes to match spaces.
  + widget: Fix mem leak in search_rows().
  + widget: Fix scrollbar drawing not to be delayed.
  + widget: Respect "bold color" even when "bold is bright" is
    disabled.
  + widget: Return correct underline value in VteCharAttributes.
  + widget: Translate more pango attributes in the IM string.
* Tue Jan  9 2018 dimstar@opensuse.org
- Update to version 0.51.3:
  + build: Fix distcheck.
  + doc: Fix vte_terminal_get_allow_bold's description.
  + emulation: Revise the extended color escape sequences.
  + widget,emulation: Add support for overline.
  + widget:
  - Add support for blinking text.
  - Fix display glitches around hidden underline.
  - Speed up the drawing of curly underline by caching its look.
* Sat Dec 16 2017 zaitor@opensuse.org
- Update to version 0.51.2:
  + sgr-test.sh: New script for testing SGR escape sequences.
  + widget, emulation:
  - Add support for colored underlines.
  - Add support for double and curly underlines.
  + widget:
  - Add support for not automatically brightening bold colors.
  - Remove margin bell support-
  - Add support for increased line and character spacing.
  - Reset might need to start blinking the cursor.
  + interpret:
  - Add statistics output.
  - Fix for non-ASCII characters decoding.
  - Also print value arrays.
  + build:
  - Rename header file.
  - Manually generate the C source from the vala source.
  + interpret: Bring back the matcher test.
  + emulation:
  - Simplify sequence matching.
  - Simplify sequence handlers and parameter handling.
  + table:
  - Remove unnecessary null checks.
  - Move header to table.hh.
  + app: Fix a mem leak.
  + pty: Fix mem leak.
  + matcher: Fix memory leak.
- Drop upstream fixed patches:
  + vte-fix-memory-leaks.patch.
  + vte-widget-reset-might-need-to-start-blinking-the-cursor.patch.
* Sat Dec 16 2017 dimstar@opensuse.org
- Exclude doc/vttest* while generating the git tarball: the vttest
  program is not being used and the version tracked in git contains
  a non-commercial clause.
* Sat Dec  9 2017 zaitor@opensuse.org
- Add vte-fix-memory-leaks.patch: Fix memory leaks (bgo#790539).
- Add
  vte-widget-reset-might-need-to-start-blinking-the-cursor.patch:
  widget: Reset might need to start blinking the cursor
  (bgo#790536).
- Drop gnome-pty-helper Obsoletes: Not present in any currently
  supported opensuse release.
- Modernize spec, run spec-cleaner, switch to to autosetup,
  make_build and make_install macros.
- No longer export fPIE/pie SUID_CFLAGS/SUID_LDFLAGS, not needed
  anymore.
* Thu Nov 16 2017 dimstar@opensuse.org
- Update to version 0.51.1:
  + App:
  - Add new test application.
  - Add opacity test mode.
  - Default to the right operator when showing a background
    image.
  - Try to make geometry work also for no-geometry-hints case.
  + Debug:
  - Fix printing the sequence string.
  - debug: Pass the known string length.
  + emulation: Add support for REP (repeat preceding graphic
    character).
  + table: Improve debug message.
  + vala: add metadata to make Terminal.spawn_async () appear in
    the VAPI.
  + widget:
  - Add API to set the operator used to draw the terminal
    background.
  - widget: Add accessor function to get scrollback lines number.
  - Add accessor functions for properties.
  - Deprecate geometry helpers.
  - Emit title-changed and uri-changed only if the value really
    changed.
  - Factor out underline and strikethrough position and
    thickness.
  - Fix a crash with hyperlinks if the mouse is over the padding.
  - Fix initial size in presence of non-default padding.
  - Queue a redraw if the background operator changes.
  - Rename char_width and char_height to cell_width and
    cell_height.
  - Show padding in size request debug output.
  - Show the mouse pointer when a popover is presented from
    outside VTE.
  + Updated documentations.
  + Updated translations.
* Wed Nov  1 2017 badshah400@opensuse.org
- Update to version 0.50.2:
  + widget:
  - Show the mouse pointer when a popover is presented from
    outside VTE (bgo#789390).
  - Emit title-changed and uri-changed only if the value really
    changed (bgo#782863).
  + Updated translations.
* Tue Oct  3 2017 zaitor@opensuse.org
- Update to version 0.50.1:
  + emulation: Add support for REP (repeat preceding graphic
    character).
  + widget:
  - Fix initial size in presence of non-default padding.
  - Fix a crash with hyperlinks if the mouse is over the padding.
* Mon Oct  2 2017 jengelh@inai.de
- Update package summaries. Replace old RPM shell vars by new
  constructs. Avoid running fdupes across partition boundaries.
  Drop --with-pic which is useless for --disable-static builds.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 0.50.0:
  + widget: Fix a crash with hyperlinks if the mouse hasn't entered
    the widget.
  + Updated translations.
* Tue Sep  5 2017 zaitor@opensuse.org
- Update to version 0.49.92:
  + pty:
  - spawn: Always fill in the GError on failure.
  - Removed unused variable.
  + docs: Fix hyperlink signal name.
  + build:
  - vala:
    . Bump vapigen required version to 0.24.
    . Fix check for valac >= 0.31.1.
  + img.sh: Fix for newer ImageMagick.
  + docs: Remove an obsolete comment.
  + widget:
  - Fix allow-hyperlink's default.
  - Provide a way to copy the selection to clipboard as HTML.
  - Don't hide the mouse pointer when a popover is presented.
  - Use lighter dashed underline for hyperlinks.
  + Don't set variables to values that are never used.
  + emulation: Swallow iterm2 OSC 133.
  + Fix the generation of the signal marshallers.
  + Emit beep on the window instead of the display.
  + Updated translations.
- Drop vte-fix-signal-marshallers-generation.patch: Fixed upstream.
* Thu Jul 20 2017 zaitor@opensuse.org
- Add vte-fix-signal-marshallers-generation.patch: Fix build with
  new glib, patch from upstream git.
* Thu May 18 2017 zaitor@opensuse.org
- Update to version 0.49.1:
  + emulation:
  - Character deletion switches to hard line ending.
  - Disregard bce only when autowrapping to the new line.
  + build:
  - Revert "build: Fix building the vala test app with builddir
    != srcdir".
  - Disable vala for distcheck.
  + vteapp: Remove an unused variable.
  + spawn: async:
  - Release reference to VteTerminal.
  - Check for nullptr before unreffing.
  + emulation: Swallow OSC 8.
  + widget:
  - Support italic in HTML copy-paste target.
  - Remove the VteIntCell and VteIntCellAttr unions.
  - Add more xkb layout switching codes to the list of modifiers.
  - Clean up the mouse pointer displaying logic.
  + Remove custom definition of howmany().
  + ring:
  - Tiny code cleanup: maintain GString integrity.
  - Invert colors for the stream's cells if debugging the ring.
  + widget,emulation: Add support for OSC 8 hyperlinks (HTML-like
    anchors).
  + Updated translations.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 0.48.3:
  + widget: Add more xkb layout switching codes to the list of
    modifiers.
  + pty: spawn: Always fill in the GError on failure.
  + build:
  - vala: Bump vapigen required version to 0.24.
  - vala: Fix check for valac >= 0.31.1.
  + emulation: Disregard bce only when autowrapping to the new
    line.
  + Updated translations.
* Sat Apr 15 2017 opensuse-packaging@opensuse.org
- Update to version 0.48.2:
  + spawn: async:
  - Release reference to VteTerminal.
  - Check for nullptr before unreffing.
  + emulation: Swallow OSC 8.
* Wed Mar 22 2017 zaitor@opensuse.org
- Update to version 0.48.1:
  + build: Revert "build: Fix building the vala test app with
    builddir != srcdir".
  + build: Disable vala for distcheck.
- Drop vte-revert-29fb71d3.patch: Fixed upstream.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 0.48.0:
  + stream: Use explicit_bzero() on encryption keys if available.
  + gir: Look in the right path for vtetypebuiltins.cc.
  + bindings/vala/Makefile.am: Fix vala vapi generation.
  + build:
  - Check for explicit_bzero().
  - Fix compilation of unittests.
  - Make sure builddir comes before srcdir.
  - Don't dist generated sources.
  - Fix building the vala test app with builddir != srcdir.
  - Fix builddir != srcdir build of check programmes.
  - Silence a compiler warning.
  + Updated translations.
- Add vte-revert-29fb71d3.patch (reverse applied): Fix building of
  VTE 0.48 (bgo#780162).
* Mon Feb 20 2017 zaitor@opensuse.org
- Update to version 0.47.90:
  + app:
  - Add MULTILINE flag for regex.
  - Fix search button sensitivity.
  - Fix button icon name.
  + widget: Fix backward search.
  + build:
  - Require vala 0.24.
  - Add --with-gtk configure switch.
  - Fix option name.
  - Try to fix configure without vala installed.
  - Hint at --disable-{introspection,vala} on error.
  + debug: Fix a typo.
  + lib:
  - Add async spawning.
  - Check out params before setting them.
  - Ressurrect the reaper.
  - Deprecate vte_terminal_spawn_sync.
  + pty:
  - Do not pass G_SPAWN_CHILD_INHERITS_STDIN.
  - Fix some leaks.
  - spawn:
    . Work around g_spawn_async non-cancellability.
    . Remove some unused code.
  + emulation:
  - Try to work with newer gperf.
  - Reset should not switch encoding.
  + docs: boxes: Add some more tests.
  + bindings: Remove gir and vala bindings to their own directory.
  + m4: Update macros from upstream.
  + Update POTFILES.skip.
  + Updated translations.
- Drop vte-emulation-Try-to-work-with-newer-gperf.patch: Fixed
  upstream.
* Mon Feb 20 2017 zaitor@opensuse.org
- Add vte-emulation-Try-to-work-with-newer-gperf.patch: Use
  language=C++ in gperf (bgo#777904).
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 0.46.1:
  + app: Add MULTILINE flag for regex
  + app: Fix search button sensitivity
  + app: Fix button icon name
  + widget: Fix backward search
  + build: Require vala 0.24
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 0.46.0:
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 0.45.92:
  + widget:
  - Fix refcount leak in child_watch_done.
  - Fix memory leak in _vte_file_stream_init().
  - Fix OSC 112 (reset cursor color).
  + docs:
  - Fix minor typo.
  - Fix missing descriptions.
  + regex:
  - Always add MULTILINE flag when translating from GRegex.
  - Warn if MULTILINE flag it not used.
  + Updated translations.
- Drop vte-widget_Fix_refcount_leak_in_child_watch_done.patch:
  Fixed upstream.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Tue Aug 23 2016 zaitor@opensuse.org
- Add vte-widget_Fix_refcount_leak_in_child_watch_done.patch: Fix
  a memory leak, patch from upstream git (bgo#770036).
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 0.45.90:
  + widget: Fix a memory leak in set_colors
  + Add Language headers to po files
  + regex: Translate GRegex to PCRE2
  + regex: Require PCRE2
  + widget: gtk: Pass NULL for geometry widget
  + Updated translations.
- Enable pkgconfig(libpcre2-8) BuildRequires: Upstream now require
  this dependency.
- Add gperf BuildRequires: New dependency, that configure does not
  check for...
- Drop vte-Validate-colour-and-fix-memleak.patch and
  vte-widget_get_preferred_height.patch: Fixed upstream.
- Switch to sourceservice, following this, no longer use url for
  source, and add gnome-common BuildRequires and boostrap tarball.
- Add gtk-doc BuildRequires and pass --enable-gtk-doc to configure,
  since we no longer use a upstream tarball we have to build the
  documentation ourselves.
* Sun Jul 31 2016 zaitor@opensuse.org
- Add vte-Validate-colour-and-fix-memleak.patch: Validate colour
  values and fix a memory-leak (bgo#768994).
* Sat May 28 2016 zaitor@opensuse.org
- Add vte-widget_get_preferred_height.patch:
  widget_get_preferred_height: use vertical padding, not
  horizontal. Corresponding patches in gnome-terminal. Patch from
  upstream git (bgo#760944).
* Tue May 24 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Thu May 12 2016 zaitor@opensuse.org
- Update to version 0.44.2:
  + emulation:
  - Swallow urxvt OSC 777.
  - Don't use smart tabs if the cells are already in use.
  - Fix Tab not to alter the background color.
  + terminal:
  - Fix search return value.
  - Fix ::get_text start column not to be negative.
  + test: Typo fix.
  + build: Fix the build when an older vte VAPI is present on the
    system.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Tue Apr 12 2016 dimstar@opensuse.org
- Update to version 0.44.1:
  + widget: Properly remove the cursor from its old position
    (bgo#764299).
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 0.44.0:
  + No changes, version bump only.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 0.43.92:
  + Bugs fixed: bgo#756141, bgo#762963, bgo#763538.
* Tue Mar  1 2016 dimstar@opensuse.org
- Update to version 0.43.91:
  + widget: Don't deselect when updating the clipboard
    (bgo#762446).
* Thu Feb 18 2016 zaitor@opensuse.org
- Update to version 0.43.90:
  + docs: Fix the build.
  + regex: Disable PCRE2 for 0.44.
  + pty:
  - Set COLORTERM variable.
  - Comment cleanup.
  + vtegtk: use CSS name for widget style.
  + lib:
  - Add some missing includes.
  - Move all colour defines to the same place.
  - Remove private header.
  - Remove VteTerminalPrivate from public headers.
  - Build fix.
  - Remove unused prototypes.
  - Remove accidentally committed debug spew.
  + build:
  - Update C++ version check macros from autoconf archive.
  - print version of libpcre2-8 when not found.
  + widget:
  - Change function name.
  - Rename instance members.
  - Move some methods to VteTerminalPrivate.
  - Correct comment.
  - Fix check for changed screen in process_incoming.
  + a11y: Move code into the only caller.
  + app: Fix return value.
  + emulation: Track the cursor separately for the two screens.
- Disable pkgconfig(libpcre2-8) BuildRequires: Upstream removed it
  again for this release, leaving it in place since it is said to
  be back next release round.
* Fri Feb 12 2016 fcrozat@suse.com
- Bump BuildRequires to gtk+ 3.16, which is required to build vte
  test application.
* Fri Feb 12 2016 dimstar@opensuse.org
- Update to version 0.43.2:
  + emulation: Fix stupid typo.
* Fri Feb 12 2016 dimstar@opensuse.org
- Upadte to version 0.43.1:
  + widget:
  - Add debug output when setting geometry hints.
  - Document how to scroll a VteTerminal (bgo#760718).
  - Don't make the VteTerminal app paintable.
  - Fix missing braces.
  - Fix crash when destroyed while waiting for clipboard text.
  + a11y: Use VteTerminal private data directly.
  + Bugs fixed: bgo#760635, bgo#734920, bgo#759346, bgo#759314,
    bgo#759196, bgo#759197, bgo#759054, bgo#726191, bgo#747046,
    bgo#741402, bgo#688456, bgo#695011, bgo#758501.
  + Updated translations.
* Fri Feb 12 2016 zaitor@opensuse.org
- Update to version 0.43.0:
  + doc: Fix vte-regex's section.
  + widget:
  - Implement smooth scrolling.
  - Filter out most of the control characters when pasting.
  + vteapp: Fix option.
  + regex:
  - Fix crash on match_check.
  - Don't expose PCRE2 in the API.
  - Forbid \C in regexes.
  - Fix row number in the new vte_terminal_event_* methods.
  - Fix parameter name in documentation.
- Add pkgconfig(libpcre2-8) BuildRequires: New optional dependency.
* Thu Feb 11 2016 zaitor@opensuse.org
- Update to version 0.42.4:
  + emulation: Track the cursor separately for the two screens
    (bgo#761097).
* Fri Jan 29 2016 zaitor@opensuse.org
- Update to version 0.42.3:
  + widget:
  - Fix missing braces.
  - Fix the adjustment's upper boundary.
  + app: Disable menubar accel.
- Changes from version 0.42.2:
  + Updated translations.
* Wed Oct 14 2015 zaitor@opensuse.org
- Update to version 0.42.1:
  + emulation:
  - Implement DECSET 1004.
  - Fix comment.
  + widget:
  - Fix regex matches not always being recognized.
  - Fix painting the preedit text near the right margin.
  + a11y: Emit missing space character insertion.
  + Updated translations.
* Tue Sep 22 2015 zaitor@opensuse.org
- Update to version 0.42.0:
  + widget: Fix regex matches not always being recognized.
  + emulation:
  - Fix comment.
  - Implement DECSET 1004.
  + tests: mev: Add focus tracking mode.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 0.41.90:
  + build:
  - Fix make dist
  - Fix the required gnutls version
  - Add libc++ check to check-libstdc++.sh
  - Fix build when using C++11 mode
  - Add C++ infrastructure
  - Fix srcdir != builddir issue
  - m4:
    . Respect language
    . Fix m4 warning about missing AC_LANG_SOURCE
    . Update from upstream
  - Remove obsolete gtk check
  + ring: Make assertion more informative (bgo#753025).
  + widget: Ensure cursor is shown when blinking gets turned off
  + emulation:
  - Fix escape sequence of Ctrl+Backspace
  - Fix vertical positioning after resize in some rare cases
  + docs:
  - Fix typo in function name
  - Add missing symbols to sections.txt
  + Remove check for unused fwrite_unlocked function
  + stream:
  - Fix a crash on truncate followed by reset
  - Don't nest VteIv's definition
  + pty:
  - Reset SIGQUIT handler to its default
  - Remove PTY helper
  - More correct assertion
  + all:
  - Fix includes
  - Move to C++
  - Reorganise source tree
  - Fix compilation with CC=g++
  - Update version check to stable version
  + lib:
  - Make VteTerminalPrivate a C++ class
  - Move define to the few places where it is used
  - Move defines to vtedefines.hh
  - Add missing G_BEGIN/END_DECLS
  + emacs: Adjust settings for C++ mode too
  + git.mk: Update from upstream
  + Updated translations.
- Add gcc-c++ BuildRequires following upstream port to gcc-c++
- Drop gnome-pty-helper supackage and obsolete it and drop
  gnome-pty-helper Requires in the main package, following
  upstream changes.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 0.40.2:
  + stream: Fix a crash on truncate followed by reset (bgo#748484).
  + pty: Reset SIGQUIT handler to its default (bgo#748520).
  + lib: Add missing G_BEGIN/END_DECLS.
- Changes from version 0.40.1:
  + emulation: Fix vertical positioning after resize in some rare
    cases (bgo#747059).
  + pty: More correct assertion (bgo#746667).
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 0.40.0:
  + updated translations.
* Thu Mar 19 2015 dimstar@opensuse.org
- Update to version 0.39.92:
  + Bugs fixed: bgo#372777, bgo#744837, bgo#745074, bgo#745131,
    bgo#745471, bgo#730632, bgo#730632.
  + Updated translations.
* Wed Feb 18 2015 dimstar@opensuse.org
- Update to version 0.39.90:
  + Bugs fixed: bgo#166637, bgo#446533, bgo#664611, bgo#678042,
    bgo#704960, bgo#725909, bgo#725909, bgo#730632, bgo#738601,
    bgo#742320, bgo#742501, bgo#742606, bgo#743073, bgo#743231,
    bgo#743258.
- Update BuildRequires to match current configure checks:
  + Removed gtk3-devel, ncurses-devel.
  + Add pkgconfig()-style: gio-2.0, gio-unix-2.0, glib-2.0, gnutls,
    gobject-2.0, gtk+-3.0, pango, zlib.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 0.39.1:
  + ring:
  - Add _vte_ring_reset().
  - Don't create streams for the alternate screen.
  + emulation:
  - Modify erase-in-line when cursor is beyond the last column.
  - Fix crash in restore-cursor without a preceding save-cursor.
  - Change soft reset not to switch back to normal screen.
  - Change window manipulation sequences only perform one action.
  + widget:
  - Do not leave behind a zombie child when closing a terminal.
  - Reap only when a child is present.
  + pty: Default to TERM=xterm-256color.
  + build: Drop unitables.
  + doc: Update iso2022.txt: keep only the supported ones and fix
    British.
  + stream:
  - Implement with one file descriptor.
  - Compress data with zlib.
  + Rebuild box_drawing.h if generator script changes.
  + Updated translations.
* Tue Dec 16 2014 zaitor@opensuse.org
- Update to version 0.39.0:
  + emulation:
  - Save/restore alternate charset.
  - Drop support for default/UTF-8 character set escape
    sequences.
  - Drop ISO-2022 support.
  - Add support for C1 control codes.
  - Add support for DECSCUSR (set cursor style).
  + widget:
  - Fix installing the CJK ambiguous width property.
  - Draw attributes on box drawing characters.
  - Remove colon from word chars.
  - Add functions to get the version at runtime.
  - Fix advance_tail if tail is not in the stream.
  + build: Add a missing return value.
  + Updated translations.
* Tue Dec 16 2014 zaitor@opensuse.org
- Update to version 0.38.3:
  + widget:
  - Fix installing the CJK ambiguous width property.
  - Do not leave behind a zombie child when closing a terminal.
  - Reap only when a child is present.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 0.38.2:
  + widget: Check cursor's display before using it.
  + docs: Remove version markers.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 0.38.1:
  + Prevent redefinition of VteCharAttributes as that breaks
    GCC 4.2.
  + Updated translations.
* Sun Sep 14 2014 zaitor@opensuse.org
- Update to version 0.38.0:
  + build: Try fixing builddir != srcdir build.
  + glade:
  - Make catalogue parallel-installable with vte 2.90.
  - Update list of properties (bgo#736508).
  + widget:
  - Rename beep signal to bell (bgo#602726).
  - Remove broken visual bell support (bgo#602726).
  - Make dim color handling more xterm-like (bgo#735245).
  - Fix theming (bgo#735081).
  + vteapp:
  - Make the bell option consistent between the two test apps.
  - Three-state bell option (bgo#602726).
  + Do not use deprecated AM_PROG_CC_STDC (bgo#736180).
  + emulation: Fix sed mistake (bgo#735024).
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 0.37.90:
  + vte.sh: Fix tilde replacement for bash-4.3 (bgo#733504).
  + Various emulation fixes (bgo#731155, bgo#731205).
  + Bugs fixed: bgo#730632, bgo#727587, bgo#657960.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 0.37.2:
  + Bugs fixed: bgo#730800, bgo#731788, bgo#731427, bgo#730858,
    bgo#730760.
- Pass --enable-gnome-pty-helper to configure: enable the helper.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 0.37.0:
  + New API: vte-2.91.
  + Many improvements and bug fixes.
  + Updated translations.
- Add pkgconfig(vapigen) BuildRequires: New dependency.
- Bump so, api and bin versions following upstream changes.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 0.36.3:
  + Important bug fixes.
  + Bug fixes.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 0.36.2:
  + widget: Update background when opacity is changed (bgo#730023).
  + vteapp: Unbreak transparency (bgo#729884).
  + emulation: Change bracketed paste mode to per-terminal.
  + docs: Fix licence header.
* Tue Apr 29 2014 dimstar@opensuse.org
- Update to version 0.36.1:
  + Fix qemu crash (bgo#728051).
  + Updated translations.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 0.36.0:
  + Build fixes (bgo#726604).
  + Docs updates.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 0.35.90:
  + Prompt: Use precmd hook on zsh (bgo#724982).
  + Fix many compiler warnings.
  + Remove obsolete gtk+-2.0 conditional code.
  + Support OSC 19 and 119 sequences (bgo#725974).
  + Also pass Ctrl-F1 to applications (bgo#726438).
  + Nicer box drawing characters (bgo#709556).
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 0.35.2:
  + Colour palette handling fixes (bgo#640040).
  + Add support for OSC 104 (reset colors) (bgo#640040).
  + Add support for OSC 1?1[017] (fg, bg, highlight colors)
    (bgo#640040).
  + Add support for OSC 112 (reset cursor color) (bgo#640040).
  + Make OSC response use the same terminator as the query
    (bgo#722446).
  + Maintain selection when rewrapping (bgo#722635).
  + Fix selection with widget padding adjustment (bgo#722873).
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 0.35.1:
  + Support for 16 million colors (bgo#704449).
  + Fix Home/End and some other keys (bgo#600659, bgo#643233,
    bgo#710349).
  + Add API to enable/disable rewrap on resize (bgo#336238).
  + Fix a longstanding performance regression (bgo#721944).
  + Bugs fixed: bgo#586950, bgo#619891, bgo#672210, bgo#685759,
    bgo#691972, bgo#720977, bgo#721522.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 0.35.0:
  + Build fixes.
  + Portability fixes (bgo#710165).
  + Bugs fixed: bgo#4993, bgo#13299, bgo#336238, bgo#542087,
    bgo#686097, bgo#693013, bgo#705985, bgo#709692, bgo#709584,
    bgo#709930, bgo#710426, bgo#710481, bgo#710483, bgo#710484,
    bgo#710488, bgo#710486.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 0.34.9:
  + Lines disappear after positioning back the cursor (bgo#708496).
  + Garbage displayed after resizing whilst using an alternate
    screen (bgo#415277).
  + vte uses too many file descriptors (part of bgo#646098).
  + Incorrect scrollbar position after the "less" command
    (bgo#676075).
  + Add support for DEC 1007 to set the alternate scroll mode
    (bgo#518405, bgo#709060).
  + Use O_TMPFILE when available (bgo#704705).
  + Improvements to scrollback storage (bgo#637275).
  + Aborts on assertion (bgo#676075).
  + zsh - lots of blank space upon resizing VTE based terminals
    (bgo#708213).
  + Misc fixes.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 0.34.8:
  + Build fixes.
  + Fix crash on pathological fonts (bgo#708196).
  + Use correct character attributes around graphic characters
    (part of bgo#707221).
  + Make extended fore/background colour handling more xterm-like
    (bgo#616436).
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 0.34.7:
  + Honour gtk-enable-primary-paste setting.
  + Redraw when changing colours (bgo#702415).
* Thu Jul  4 2013 dimstar@opensuse.org
- Move vte.sh to gnome-pty-helper subpackage: vte.sh is needed for
  normal operations like starting a new tab in the same directory
  as the previous one (bnc#827248). vte-tools is a rather uncommon
  tool to be installed.
  NOTE: this on its own does not fix the issue just yet, as vte.sh
  is not being sourced by bash without further doing, as bash does
  not source files in /etc/profile.d in non-login shells.
* Sat Jun 15 2013 zaitor@opensuse.org
- Update to version 0.34.6:
  + vte.sh bugfix.
  + Add new flag for vte_terminal_fork_command_full() to not copy
    the parent environment.
  + Allow the empty string to OSC 6 and OSC 7 to unset a previously
    set value.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 0.34.5:
  + Improved vte.sh script (bgo#697475): It is now not necessary
    anymore to manually change PS1. On distributions that
    automatically source /etc/profile.d/*.sh scripts for all
    interactive shells (eg Fedora), no manual intervention is
    needed at all; for others the only change required is to source
    the vte.sh script. Also, the script now works for both bash
    and zsh shells.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 0.34.4:
  + Improved vte.sh script (bgo#697225).
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 0.34.3:
  + Introspection fixes (bgo#676999, bgo#690003).
  + Build fixes (bgo#690554).
  + Portability fixes (bgo#694494).
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 0.34.2:
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 0.34.1:
  + End selection mode misses Shift release (bgo#683730).
  + Don't report shift-left-button release (bgo#683729).
  + xterm extended mouse tracking mode (bgo#681329).
  + Support SGR 3 (italic text) (bgo#685223).
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 0.34.0:
  + Fixed drawing of Box Drawing and Block Elements characters
    (bgo#682692)
  + Introspection fixes (bgo#679805, bgo#681714)
  + Build fixes.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 0.33.90:
  + Add sequences to set current directory and file
  + pkgconfig: Remove unused default emulation variable
    (bgo#674490)
  + bash: Add /etc/profile.d/vte.sh script
  + Bugs fixed: bgo#675987, bgo#674490.
* Mon Jul 23 2012 dimstar@opensuse.org
- Update License tags to represent as cloesly as possible the right
  licenses (mostly LGPL-2.0, small parts are GPL-2.0) (bnc#770592).
* Mon Jun  4 2012 dimstar@opensuse.org
- Update to version 0.32.2:
  + emulation: Fix DoS by malicious escape sequences (bgo#676090)
  + widget: Fix crash with NULL tag in match_check (bgo#676886)
  + keymap: Treat ALT as META (bgo#663779)
- Drop vte-keymaps.patch: merged upstream.
* Thu May 17 2012 dimstar@opensuse.org
- Add vte-keymaps.patch: keymap: Treat ALT as META. [bnc#754350,
  bgo#663779].
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 0.32.1:
  + emulation: Fix off-by-one error in interpretation of ECH
    (bgo#670037)
  + pty: Fix custom child setup function (bgo#672649)
  + Fix leak in vte_draw_set_text_font() (bgo#672757)
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 0.32.0:
  + Use GResource for our default termcap.
  + Build fixes for interix (bgo#652290).
  + Allocate PTYs with openpty on BSD (bgo#670758).
  + Introspection fixes (bgo#648183, bgo#655402, bgo#661716).
  + Fix mouse whell scrolling with gtk+ 3.4 (bgo#671305).
  + Use correct library name for glade integration (bgo#671760).
  + gnome-pty-helper: Respect SUID_CFLAGS and SUID_LDFLAGS
    (bgo#67073).
- Drop vte-suid_flags.patch: fixed upstream.
- Remove autoconf and automake BuildRequires, and no longer call
  autoreconf in gnome-pty-helper subdirectory, as we don't carry
  any patches anymore.
* Fri Feb 24 2012 vuntz@opensuse.org
- Add vte-suid_flags.patch: respect SUID_CFLAGS/SUID_LDFLAGS when
  building the suid binary gnome-pty-helper.
- Set SUID_CFLAGS to -fPIE and SUID_LDFLAGS to -pie in %%build. This
  fixes bnc#743135.
- Add autoconf and automake BuildRequires, and call autoreconf in
  gnome-pty-helper subdirectory, for the new patch.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Vte-2_90 subpackage.
- Add typelib-1_0-Vte-2_90 Requires to devel subpackage.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 0.31.0:
  + Don't override the widget background colour
  + Add missing (closure) annotation on VteSelectionFunc
  + use gtk_drag_check_threshold() (bgo#654691)
  + Add urxvt extended mouse tracking mode support (bgo#662423)
  + Add runtime check for X11 display (bgo#660151)
  + Bugs fixed: bgo#655405, bgo#661121, bgo#616001
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 0.30.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 0.30.0:
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 0.29.1:
  + bgo#657581: gdk-3.0 supports multiple targets; the "target"
    variable is gone
  + bgo#657584: vte needs to properly set VTE_API_VERSION
- Changes from version 0.29.0:
  + Drop GTK 2 support
  + Fix accessibility with GTK 3.1 (bgo#654630)
  + Updated translations.
- Drop vte2 source package that was kept in sync with this source
  package since the GTK+ 2 support got dropped. Also remove
  build_for_gtk2 macro, and anything that was related to it.
- Add pkgconfig(gladeui-2.0) BuildRequires, and enable the build of
  the glade catalog again:
  + Drop build_glade_catalog macro (by doing as if it was set to 1)
  + Rename glade3-catalog-vte to glade-catalog-vte. Note that there
    is no Provides/Obsoletes as the files are different, and there
    is still a glade3 package for which the catalog would not work.
  + Change libvte9 Requires in glade-catalog-vte to
    libvte%%{_sover}.
* Wed Jun 15 2011 vuntz@opensuse.org
- Update to version 0.28.1:
  + bgo#652124: malicious escape sequence causes gnome-terminal to
    exhaust memory
  + Updated translations.
* Wed May 18 2011 vuntz@opensuse.org
- Drop rpmlintrc as the new path for gnome-pty-helper is now known
  by the permissions system.
* Thu May  5 2011 vuntz@opensuse.org
- Use %%set_permissions instead of deprecated %%run_permissions in
  %%post of gnome-pty-helper.
- Move %%verify_permissions to %%verifyscript of gnome-pty-helper.
- Only put gnome-pty-helper scriptlets if %%{build_for_gtk2} is not
  set, since we don't build gnome-pty-helper when building for
  gtk2.
* Wed Apr 27 2011 vuntz@opensuse.org
- Split gnome-pty-helper in its own package, and stop installing it
  in a non-default libexecdir: it is needed by both gtk2 and gtk3
  versions of vte, and we don't want to have it twice. So only keep
  the one we get with the gtk3 build.
- Add Requires for gnome-pty-helper to libvte9 and libvte2_90.
- Update rpmlintrc accordingly.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.28.0:
  + bgo#642184: vte does not build against new glade (with
    gladeui-2.0).
  + Updated translations.
- Changes with version 0.27.90:
  + Remove gsettings .enums.xml.
  + Fix shrinking terminal on gtk3
  + Updated translations.
- Changes with version 0.27.5:
  + Fix build with recent GTK+
  + Updated translations.
- Changes with version 0.27.4:
  + Fix build with recent GTK+
  + Introspection fixes for fork_command_full
  + Updated translations.
- Changes with version 0.27.3:
  + Add a gsettings .enums.xml file for vte's enum types
  + Fix build with latest gtk 3
  + Fix introspection annotations and require gobject-introspection 0.9.0
  + Bugs fixed: bgo#628870.
  + Updated translations.
- Changes with version 0.27.2:
  + GTK+ 3 fixes.
  + Updated translations.
- Changes with version 0.27.1:
  + Bugs fixed:
  - bgo#631589: Pass the correct TERM value inside envp when
    spawning
  - bgo#631903: Report correct minimum/natural sizes for GTK+ 3
  - bgo#632257: vte leaks FDs
  + Updated translations.
- Add pre_checkin.sh to build gtk2 and gtk3 version of the package
  and add some macros to handle dual gtk2 / gtk3 packages.
- Differences between gtk2 / gtk3 packages:
  + Pass --with-gtk=2.0/--with-gtk=3.0 to configure as appropriate.
  + python-vte is only built for gtk2, as introspection is used for
    gtk3.
- Disable glade catalogue build for gtk3 with build_glade_catalog
  macro, as we don't have a gtk3-powered glade right now.
- Remove %%py_requires from main package since we don't build a vte
  binary package.
- Add rpmlintrc files to avoid a permissions-file-setuid-bit error
  that makes the build fail. Security team will review that
  (bnc#690202).
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 0.26.2:
  + bgo#632257: Plug FD leak.
* Tue Nov 16 2010 aj@suse.de
- Use group utmp for gnome-pty-helper (bnc#652877).
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 0.26.1:
  + Pass the correct TERM value inside envp when spawning.
  + bgo#631589: set_emulation does not work in the python bindings
* Tue Oct  5 2010 vuntz@opensuse.org
- Split vte according to the shared library policy (bnc#634199):
  + create libvte9, vte-tools, python-vte, glade3-catalog-vte
    subpackages.
  + add Provides/Obsoletes for vte to libvte9, for migration and
    for the lang package
  + use Recommends for the lang package in libvte9
  + add glade3 Requires to glade3-catalog-vte, as well as a
    Supplements for packageand(glade3:vte-devel) for automatic
    installation for people who are developing with VTE.
  + use {_libexecdir}/libvte9 as libexecdir, to potentially have
    multiple versions of gnome-pty-helper parallel-installable (the
    protocol used between the helper and vte could change).
- The glade3-catalog-vte subpackage is part of bnc#637694.
- Remove explicit Requires of devel packages in vte-devel: they
  will be added automatically the pkgconfig() way.
- Update summaries and descriptions.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.26.0:
  + Clarify TERM env var handling with VtePty.
  + Build fixes.
  + Updated translations.
* Sun Aug 29 2010 dimstar@opensuse.org
- Update to version 0.25.91:
  + bgo#627764: mismanaged GtkStyle lifecycle
  + bgo#601926: Don't hardcode meta to alt
  + Various build fixes.
  + Updated translations
* Tue Aug 24 2010 vuntz@opensuse.org
- Add gobject-introspection-devel BuildRequires and pass
  - -enable-introspection to configure to build introspection
  support.
* Mon Aug 16 2010 dimstar@opensuse.org
- Update to version 0.25.90:
  + Make vte parallel-buildable with gtk 2 and gtk 3
  + Bugs fixed:
  - bgo#617690: Setting default fg color should not cancel
    underline
  - bgo#614658: text selection with mouse is buggy when using
    the shift key
  - bgo#618749: set terminal widget background color to terminal
    background
  - bgo#601926: Don't hardcode meta to alt
  - bgo#618097: Broken backtab (cbt)
  - bgo#621298: Cursor invisible (plain black) in (xfce) Terminal
    & terminator
  - bgo#626676: Cleanup vte_terminal_determine_colors
  - bgo#620493: strict aliasing warning
  + Translation updates.
* Tue Jul 13 2010 dimstar@opensuse.org
- Update to version 0.25.1:
  + Add support for searching the buffer. New public API:
  - vte_terminal_search_[sg]et_regex
  - vte_terminal_search_find_(previous|next)
* Wed Jun 23 2010 dimstar@opensuse.org
- Update to version 0.24.2:
  + Fix reversed logic for saturation level of background.
  + Build fixes.
  + Updated translations.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 0.24.1:
  + bgo#613525: current git head does not build (undefined
    reference to XGetGeometry)
  + bgo#614469: Does no longer compile with -DX_DISPLAY_MISSING
  + bgo#615417: Reversed and one error saturation level in 0.24.0
- Drop vte-0.24.0-no-transparent-background-bnc594590.patch,
  merged a more complete patch.
* Tue Apr 13 2010 andrea@opensuse.org
- Add vte-0.24.0-no-transparent-background-bnc594590.patch to fix
  segfaults on programs using vte (lxterminal, gnome-terminal)
  with a transparent background. Fix bnc#594590.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 0.24.0:
  + Updated API docs
  + Cache backgrounds as cairo surfaces
  + Updated translations.
- Add libgladeui-1_0-devel BuildRequires and pass
  - -enable-glade-catalogue to configure to build the glade catalog.
- Use libexedir instead of prefix/lib.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 0.23.5:
  + Fix unintented soversion bump
- Changes from version 0.23.4:
  + Add public API vte_terminal_write_contents()
  + Update docs
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 0.23.3:
  + Disable symbol deprecation stuff since they were broken
  + Merge pangocairo draw impl into vtedraw
  + bgo#534526 - Flickering when resizing a vte widget
  + bgo#605299 - Please support xterm bracketed paste mode
* Tue Dec 22 2009 vuntz@opensuse.org
- Update to version 0.23.2:
  + Fix overflow with unlimited scrollback lines
  + Require glib >= 2.22.0
  + Deprecate vte_terminal_get_padding
  + Add VteTerminal::inner-border style property
  + vteapp: Add --cursor-shape option
  + Bugs fixed:
  - bgo#604966 - Fix "select all" to include text occurring after
    the visible region
  - bgo#604135 - [PATCH] fix behaviour of set-scrolling-region
  - bgo#603733 - Remove deprecated Glib symbol
  - bgo#603713 - ibeam/underline cursor broken with large
    inner-border
  - bgo#471920 - Expose the border width property
  - bgo#601265 - gnome-terminal assert failure:
    table.c:723:_vte_table_match
  - revert fix for bgo#591648 - Don't clear the screen when
    switching to the alternate screen
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 0.23.1:
  + Various crash and bug fixes
  + Rework mouse selection to be more robust.  In particular,
    PRIMARY selection now only changes when mouse button is
    released, not upon every motion when selecting.
  + Interpret and document negative number of scrollback lines as
    infinite
  + We now chain unhandled motion-notify events up such that the
    parent widget can give them a shot.
  + Bugs fixed:
  - bgo#597604 - assertion failed: (_vte_ring_contains (ring,
    position))
  - bgo#598124 - The selection does not only change when the
    mousebutton is released
  - bgo#598090 - LMB Mouse up event not registered when opining
    context popup menu
  - bgo#587463 - "select all"+copy from gnome-terminal includes
    lines no longer in scrollback
  - bgo#585370 - Incomplete disabling of python
  - bgo#597242 - libvte color and cursor glitches
  - bgo#591648 - Don't clear the screen when switching to the
    alternate screen
  - bgo#595445 - Motion notify events are not propagated to
    parent widget
  - bgo#569184 - vte generates unnecessary ioctl(I_FIND) kernel
    warnings
  - bgo#599444 - Scrollback index type mess
  - bgo#598814 - text.getText(0, -1) triggers assertion in
    vteaccess.c
  - bgo#596739 - Python bindings leak memory
  - bgo#597165 - void return in vte.c
  - bgo#587894 - the environment passing with python does no
    longer work
* Tue Sep 29 2009 dimstar@opensuse.org
- Update to version 0.22.2:
  + Fix crash introduced in previous release
  + Fix a11y assertion failure
  + Improve selection at the end of row
  + bgo#596444 - word-select includes \n when the word ends at the
    edge of the terminal
  + bgo#596460 - 0.22.1 kills vte based apps
  + lp#435646 - gnome-terminal assert failure.
* Mon Sep 28 2009 dimstar@opensuse.org
- Update to version 0.22.1:
  + bgo#596365 - libvte crashes when issueing 'reset' in a terminal
  + bgo#588033 - background tabs may lose lines off the bottom of
    the scrollback
  + bgo#596163 - Doesn't display expected background color in
    ncurses apps
  + bgo#596011 - Problem compiling vte 0.22.0 on Solaris
- Changes from previous versions:
  + Fix tab and wide-char handling
  + Another rewrite of the ring.  Stores ring data on tmp files on
    disk now.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.21.5:
  + Finish ring rewrite.  Scrollback buffer consumes ten times less
    memory now, and better, doesn't allocate from the heap, so
    closing tabs actually releases memory.
* Fri Aug 28 2009 dimstar@opensuse.org
- Update to version 0.21.4:
  + Remove another stale assert()
  + Oops, use the right map decoding function is iso2022 code
- Changes from version 0.21.3:
  + Really fix the ring this time
  + Enable g_assert().  May trigger some bogus ones now
- Changes from version 0.21.2:
  + bgo#592990 - gnome terminal crashes with glibc detected.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 0.21.1:
  + Redesigning the vte buffer ring is going on.  Please report any
    misbehavior
  + Bugs fixed in this release:
  - bgo#590824 - gnome-terminal crashed with SIGSEGV after hiting
    ctrl+o
  - bgo#572230 - text mode program rendering is strange in cjk
    locale.
  - bgo#588200 - bashisms in shell scripts
* Wed Jun 10 2009 vuntz@novell.com
- Update to version 0.20.5:
  + Followup release to undo unintentded .soname bump.
* Tue Jun  2 2009 vuntz@novell.com
- Update to version 0.20.4:
  + New enum value VTE_ERASE_TTY.
  + Make VTE_ERASE_AUTO send \H for backspace if terminal erase is
    undefined.
  + bgo#584281 - build: avoid double installation of xterm
  + bgo#543379 - VTE sends NUL/^@ for backspace
* Wed May 27 2009 vuntz@novell.com
- Update to version 0.20.3:
  + bgo#583129 - [python] allow passing None as command or
    directory option
  + bgo#583078 - [python] allow passing of environment as a
    dictionary
* Tue May  5 2009 vuntz@novell.com
- Update to version 0.20.2:
  + bgo#567064 - Work around buggy iconv
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 0.20.1:
  + bgo#574491 – gnome-pty-helper can prevent volumes from being
    unmounted
  + bgo#576504 – vte does not pass its testsuite.
  + bgo#573674 – reset resets width to 80 chars
  + bgo#576797 – Double-click sometimes stops working
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 0.20.0:
  + Support using a real bold font instead of pseudo-bolding
  + Respond to fontconfig configuration changes
  + Bugs fixed: bgo#54926, bgo#570208, bgo#548272, bgo#565688,
    bgo#566795, bgo#524170, bgo#566730, bgo#565679, bgo#565675,
    bgo#565663, bgo#575398, bgo#574616, bgo#574025
- Remove -fno-strict-aliasing from CFLAGS.
- Remove unneeded BuildRequires: gtk-doc, update-desktop-files
- Merge -doc into -devel as it only contained gtk-doc
* Fri Jan 23 2009 vuntz@novell.com
- Merge versions from GNOME:Factory:Next and openSUSE:Factory.
- Remove tests for openSUSE <= 10.2.
* Mon Jan 19 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.19.4:
  + Support for correct rendering of combining characters
  + Fix background rendering.
  + Misc bug fixes.
  + bgo#564535 – check for gperf in autogen.sh
  + bgo#149631 – gnome-terminal doesn't combine combining chars in utf8
  + bgo#564057 – src/pty.c does not compile with
  - -disable-gnome-pty-helper
  + bgo#562695 - ship pkg-config file for python bindings
  + bgo#563752 – pangocairo backend recreates cairo_surface_t for
    background drawing
  + bgo#163213 – Cursor should remain visible when selected
* Sun Dec  7 2008 mboman@suse.de
- Update to version 0.19.3:
  + Really fix the rendering bug.
  + Bugs fixed: rh#474618, bgo#563274, bgo#563024, bgo#552096, bgo#559818,
    bgo#471480, bgo#110371, bgo#112172, bgo#560667, bgo#541441, bgo#562806,
    bgo#562511, bgo#540951, bgo#465036, bgo#127870, bgo#317236, bgo#107031,
    bgo#521420, bgo#514632, bgo#459553, bgo#562385, bgo#562332, bgo#562338,
    bgo#488960, bgo#561366, bgo#562187, bgo#416518, bgo#500191, bgo#514457,
    bgo#542561, bgo#560766, bgo#536894, bgo#561713, bgo#560819, bgo#560818,
    bgo#560977, bgo#561185, bgo#560817, bgo#560991, bgo#395599, bgo#557375,
    bgo#556398, bgo#339819, bgo#399364, bgo#556328, bgo#549835, bgo#509204,
    bgo#539130
  + Rewrote text selection.  Much less buggy now.  Specially block-mode.
  + Fixed rendering bug caused by wrong tab handling introduced in 0.19.0.
  + More deprecation.  VteReaper is deprecated and will be removed in 1.0.
  + Minor optimizations in the pangocairo backend.  Only one FcFontSort now
    instead of the previous two.
  + New, PangoCairo, rendering backend.  This is functionally equivalent to
    the previous default backend which was Xft.  And just a tad bit faster.
  + All other backends are removed.
  + Configurable cursor shape (block, underline, I-beam).
  + Preliminary object properties added to VteTerminal.
  + Vte now depends on glib, pango, gtk+, and nothing else.
  + API that will be removed in vte 1.0 has been marked deprecated in this
    release.
  + gnome-pty-helper does no longer depend on and link to glib
  + General code maintenance and cleanup.
  + Translation updates
* Tue Sep 23 2008 mboman@suse.de
- Update to version 0.17.4:
  + Translation updates
* Tue Sep  9 2008 maw@suse.de
- Update to version 0.17.3:
  + Update python bindings
  + Bug fixed: bgo#538344.
* Thu Aug 14 2008 mboman@novell.com
- Update to version 0.17.2:
  + Fix crasher on 64bit systems
  + Fix a bunch of warnings
  + Bug bgo#546940 â€“ Crash when selecting text
* Wed Aug  6 2008 maw@suse.de
- Update to version 0.17.1:
  + New API:
  * Make the cursor blinking follow the gtk setting by default,
    with a possible override
  * Set named cursors on matches
  * Do GRegex matching, to be used alternatively to the old
    vteregex matching
  * Add set-scroll-adjustments signal, needed to allow adding a
    VteTerminal into a GtkScrolledWindow
  * Add version check macro
  + Bugs fixed: bgo#546366, bgo#545924, bgo#542795, bgo#399744,
    bgo#510903, bgo#539130, bgo#540182, bgo#535552, bgo#535469,
    bgo#418918, bgo#535467, bgo#535468, and bgo#515972.
* Mon Jun 16 2008 maw@suse.de
- Update to version 0.16.14:
  + Bugs fixed:	bgo#536632, bgo#535022, bgo#534148, and bgo#516869.
* Thu May  1 2008 jpr@suse.de
- Remove vte-0.16.6-dont-disable-all-deprecateds.patch, the
  deprecation is handled in the configure stage now and is off by
  default.
* Fri Mar 14 2008 maw@suse.de
- Update to version 0.16.13:
  + Minor optimizations
  + Bugs fixed: bgo#517709 and bgo#449131.
* Fri Feb  1 2008 maw@suse.de
- Update to version 0.16.12:
  + More work around Gdk backends that don't issue
    GdkVisibilityNotify
  + Bugs fixed: bgo#503164 and bgo#449131.
* Wed Jan 30 2008 sbrabec@suse.cz
- Devhelp documentation moved to the separate package (bnc#248813).
* Tue Jan 29 2008 maw@suse.de
- Update to version 0.16.11:
  + Work around Gdk backends that don't issue GdkVisibilityNotify
  + Try transliteration when pasting text into a non-UTF-8 locale
  + Smart tab character: you can now copy/paste tab characters
    printed by cat, diff, and other line-oriented tools and get
    the tab character in the clipboard, instead of multiple
    spaces; the selection indicates that by being all or none
  + Bugs fixed: bnc#503164, bnc#319687, bnc#497246, bnc#412435,
    bnc#416561, bnc#416558, bnc#403217, bnc#118967, bnc#353610,
    bnc#499892, bnc#499891, bnc#499896, bnc#499893, bnc#499287,
    bnc#142640, bnc#439384, bnc#483642, and bnc#480735.
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 0.16.9:
  * Slightly improved pango backend
  * Fixed handling of wrapped links in gnome-terminal
  * Fixed troubles with pad
  * Handle Sun Cut, Copy, Paste keys
  * Fixed vteapp resize weirdness
  * Fixed spaces not underlined
  * Fixed vte crash on removing a terminal tab
  * Misc bug fixes
* Fri Aug 17 2007 maw@suse.de
- Add vte-0.16.8-bnc-300574.patch (#300574, b.g.o #450069).
* Mon Aug  6 2007 maw@suse.de
- Split off a -lang subpackage
- Use %%fdupes
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun.
* Wed Aug  1 2007 mauro@suse.de 
- Update to version 0.16.8
- Fixed missing documentation in the tarball.
- Bugfixes for #337252, #448259, #449809, #450745.
* Fri Jul  6 2007 maw@suse.de
- Update to version 0.16.6
- Bugs fixed (against bugzilla.gnome.org): #431799, #429189,
  [#415044], #414716, #429278, #440475, #375112, #440377, #433776,
  [#445620], and #372743.
* Wed Apr 11 2007 maw@suse.de
- Update to version 0.16.1, which contains:
- Lots of bug fixes by Chris Wilson
- New feature: mouse scroll-wheel now feeds three arrow-up/down keys to the
  terminal if in the "alternate" mode.  The alternate mode is used by apps
  like vim, less, emacs, screen, etc.  This makes the scroll-wheel usable
  in a state that it was of no use before.
- Bugs fixed in this release:
  * Bug #426870 - vte often passes NUL to functions requiring valid unichar
  * Bug #419644 - Links do not get highlighted anymore
  * Bug #404757 - URL matching doesn't work with PCRE
  * Bug #426541 - crash on IRM escape code
  * Bug #424184 - Make scroll wheel send Page Up/Down when it makes sense
    Original patch by Shaun McCance and refined by Baris Cicek.
  * Bug #425767 - vte_terminal_set_color_highlight should test for
    NULL before _vte_debug_print
  * Bug #422385 - vte appears at the top of the root window even when
    packed at the bottom of it Patch by Dodji Seketeli.
  * Bug #420935 - glyph can be cropped with not fitting in a cell
  * Bug #420067 - Does not handle expose events whilst processing
    unseen incoming data
  * Bug #415381 - Improve performance of vte_terminal_insert_char()
  * Bug #418073 - Opacity ignored for vtexft
  * Bug #418910 - Asymmetric scrolling with mouse wheel
  * Bug #416634 - Rendering glitch as autowrapped chars are outside
    invalidated bbox
  * Bug #416635 - Rendering glitch: double draw of line below exposed region
  * Bug #418588 - Invalid read when drawing preedit cursor
  * Bug #417652 - Scrolling bug exposed by nvi
  * Bug #417301 - Terminal widgets don't respond to DPI changes
  (These bugs are viewable on bugzilla.gnome.org).
* Fri Mar 23 2007 maw@suse.de
- Update to version 0.16.0
- b.g.o fixes include: 412361, 411000, 410534, 410463, 159078,
  411276, 410534, 411276, 414716.
* Mon Feb 19 2007 maw@suse.de
- Update to version 0.15.3
- Update and rename vte-0.14.1.dif to
  vte-0.15.3-dont-disable-all-deprecateds.patch
- Remove vte-no-pwd.dif.
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Mon Jan 15 2007 sbrabec@suse.cz
- Fixed devel dependencies.
* Fri Dec  8 2006 maw@suse.de
- Move to /usr, and remove most hardcoded paths
- BuildRequire pkg-config
* Tue Nov 28 2006 sbrabec@suse.cz
- Build as user.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 0.14.1
- Bug 358344 – autoscroll only works one way in fullscreen
- Bug 353756 – font setting cleanup
- Bug 356616 – libvte broken with new autotools
- Bug 354024 – Suppress multiple warnings for missing control sequence
  handlers
* Mon Sep 25 2006 jhargadon@suse.de
- added %%py_requires to the specfile for bug #207923
* Wed Sep  6 2006 anosek@suse.cz
- update to version 0.14.0
  o Minor doc syntax update.
  o Fix bug causing empty lines to not being copied.
  o Bug 350236 – Cannot copy text; invalid character sequence errors
  o Bug 352439 – URL highlighting seriously broken
  o Bug 351494 – Gnome-terminal doesn't kills bash on tab close
  o Bug 352365 – font caching problem for not-found glyphs
- fixed compiler warning: operation on 'tmp' may be undefined
  [#190917] (warning.patch)
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 0.13.6
- Bug 351696 – crash on Terminal, check ->window before setting
  icon/window title
- Bug 350623 – Accessible text getTextAtOffset is broken
* Wed Aug 16 2006 jhargadon@suse.de
- update to version 0.13.5
- terminal backspace behavior not set to UTF-8 mode
- Bug 348814 – crash on Terminal
- Bug 336947 – [patch] Redundant vte_terminal_set_font_full() calls
- Bug 134800 – gnome-termnal hung up when input by ATOK
- Bug 339983 – gnome-pty-helper should log username
- Bug 121904 – copy-paste of empty line
- Bug 25290 – Small UI tweak to select-by-word
- Bug 311855 – Race in vte leads to blocking of input.
- Bug 339529 – gnome-terminal (vte) crashes when detatched window is
  closed
- Bug 331803 – style needs to be attached/detached to the window on
  realize/unrealize
- Bug 339448 – selection doesn't respect hard newlines
- Bug 160782 – Vte isn't multi-screen safe
- Bug 328850 – Crash when pasting selection
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
- don't buildrequire python-gobject2-devel
- fix requires on -devel package
* Wed Aug 16 2006 ro@suse.de
- added python-gobject2-devel to BuildRequires
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 jpr@suse.de
- Fix pkgconfig file Requires.private -> Requires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 0.11.16.
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Tue Aug 23 2005 gekker@suse.de
- Update to version 0.11.15
* Thu Aug 11 2005 gekker@suse.de
- Update to version 0.11.14
* Wed Jun 22 2005 gekker@suse.de
- Update to version 0.11.13
* Wed Mar 16 2005 gekker@suse.de
- Remove .desktop file, it is just a test tool, not for menus
* Mon Mar  7 2005 gekker@suse.de
- add vte-memory-background.patch
* Thu Mar  3 2005 gekker@suse.de
- update to 0.11.12
* Tue Dec 21 2004 gekker@suse.de
- Update to version 0.11.11
- Rework patches so they apply
- Change spec file so it can find the libs
* Mon Nov 22 2004 ro@suse.de
- make specfile rpm3 compliant ...
  (non numeric if arguments need quoting)
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Tue Oct 19 2004 sbrabec@suse.cz
- Removed /opt/gnome/lib64/vte/gnome-pty-helper from permissions.
- Renamed no locale to nb.
* Tue Oct 19 2004 ro@suse.de
- use special permissions files to build on PLUS
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed libexecdir for bi-arch (#47050).
* Wed Sep 22 2004 hhetter@suse.de
- don't do pwd as command when nothing else was given
  (#45813)
* Wed May 19 2004 ro@suse.de
- do not define PANGO_DISABLE_DEPRECATED
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated to version 0.11.10.
* Fri Aug 15 2003 adrian@suse.de
- install desktop file
* Wed Aug  6 2003 ro@suse.de
- don't define GTK_DISABLE_DEPRECATED since python-gtk includes
  still use/support some old features
* Thu Jul 24 2003 hhetter@suse.de
- really prefix to /opt/gnome
- move python stuff to /usr
- %%_lib fixes
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 0.10.29.
- Use %%find_lang.
* Fri Jun  6 2003 mmj@suse.de
- Add .la to -devel
* Fri Apr  4 2003 ro@suse.de
- use wildcard in filelist for python (should use macro)
* Wed Feb 26 2003 sbrabec@suse.cz
- Make gnome-pty-helper SGID tty, not utmp.
* Tue Feb 25 2003 sbrabec@suse.cz
- Fixed %%files and FHS fix (libexecdir).
* Fri Feb  7 2003 hhetter@suse.de
- updated to version 0.10.17 [GNOME 2.2.0]
* Tue Jan 21 2003 ro@suse.de
- lib64 fix
* Thu Jan 16 2003 hhetter@suse.de
- initial SuSE package
